function [ml_k,prob_k] = bayes_lagorder(tm,curr_ini)

tm.maxp = curr_ini.ms_maxlag;
if tm.maxp==0;
   tm.maxp = 12;
end;

ml_k = zeros(tm.maxp,1);
prob_k = zeros(tm.maxp,1);
if tm.amat_type==1;
   if tm.amat_lag==1;
      A = tm.rank(tm.n+1).Omega;
   else;
      A = tm.amat_val;
   end;
   q = tm.n+2;
else;
   A = tm.lambda_a*eye(tm.n);
   q = tm.q_parm;
end;

%
% Creating data matrices in VECM form
%

for i=1:tm.maxp;
   ss_beg = tm.maxp-i+1;
   ss_end = size(tm.x0,1);
   if isempty(tm.x2)==1;
      if isempty(tm.x1)==0;
         [tm.Z0,tm.Z1,tm.Z2,tm.Z1t]=vecmdata(tm.x0(ss_beg:ss_end,:),i,tm.x1(ss_beg:ss_end,:));
      else;
         [tm.Z0,tm.Z1,tm.Z2,tm.Z1t]=vecmdata(tm.x0(ss_beg:ss_end,:),i,[]);
      end;
      tm.q = 0;
      tm.q1 = 0;
      tm.q0 = 0;
      exo = 0;
   else;
      if isempty(tm.x1)==0;
         [tm.Z0,tm.Z1,tm.Z2,tm.Z1t]=vecmdata(tm.x0(ss_beg:ss_end,:),i,tm.x1(ss_beg:ss_end,:),tm.x2(ss_beg:ss_end,:),tm.q1,i);
      else;
         [tm.Z0,tm.Z1,tm.Z2,tm.Z1t]=vecmdata(tm.x0(ss_beg:ss_end,:),i,[],tm.x2(ss_beg:ss_end,:),tm.q1,i);
      end;
      tm.q = size(tm.x2,2);
      tm.q0 = tm.q-tm.q1;
      exo = 1;
   end;
   %
   if isempty(tm.x1_r)==0;
      num = size(tm.x1_r,1);
      tm.Z1 = [tm.Z1;tm.x1_r(tm.maxp+1:num,:)'];
      tm.Z1t = [tm.Z1t;tm.x1_r(tm.maxp+1:num,:)'];
   end;
   %
   % create the prior matrices
   %
   tm.p = i;
   tm.T = size(tm.Z0,2);
   if isempty(tm.Z2)==0;
      [D_mu,D_sigma,G_mu,G_sigma] = prior_short_coint(tm);
   else;
      D_mu = [];
      D_sigma = [];
      G_sigma = [];
      G_mu = [];
   end;
   if tm.prior_inf_deter==2;
      %
      % improper prior on delta
      %
      if isempty(tm.Z2)==0;
         if tm.d>0;
            D = tm.Z2(1:tm.d,:);
            M_D = eye(tm.T)-(D'*inverse(D*D')*D);
         else;
            D = 1;
            M_D = eye(tm.T);
         end;
         if size(tm.Z2,1)>tm.d;
            Z2 = tm.Z2(tm.d+1:size(tm.Z2,1),:);
            N = M_D-(M_D*Z2'*inverse(((Z2*M_D*Z2')+inverse(G_sigma)))*Z2*M_D);
            z = det(G_sigma)*det(D*D')*det(((Z2*M_D*Z2')+inverse(G_sigma)));
         else;
            N = M_D;
            z = det(D*D');
         end;
      else;
         N = eye(tm.T);
         z = 1;
      end;
      num_z = tm.d;
   else;
      %
      % proper priors on delta and Gamma
      %
      if isempty(tm.Z2)==0;
         Z = tm.Z2;
         if tm.d>0;
            if size(tm.Z2)>tm.d;
               F_sigma = [[D_sigma zeros(tm.d,size(G_sigma,1))];[zeros(size(G_sigma,1),tm.d) G_sigma]];
            else;
               F_sigma = D_sigma;
            end;
         else;
            F_sigma = G_sigma;
         end;
         N = eye(tm.T)-(Z'*inverse(((Z*Z')+inverse(F_sigma)))*Z);
         z = det(F_sigma)*det(((Z*Z')+inverse(F_sigma)));
      else;
         N = eye(tm.T);
         z = 1;
      end;
      num_z = 0;
   end;
   C_1 = (tm.Z1*N*tm.Z1')+((1/(tm.lambda_alpha^2))*eye(tm.n));
   S = A+(tm.Z0*N*tm.Z0')-(tm.Z0*N*tm.Z1'*inverse(C_1)*tm.Z1*N*tm.Z0');
   %
   log_k1 = ((q/2)*log(det(A)))-( ((tm.T-num_z)*(tm.n/2)*log(pi)) + ((tm.n/2)*log(z)) + gamma_product(tm.n,q) );
   %
   ml_k(i,1) = log_k1 + gamma_product(tm.n,tm.T+q-num_z) - ((tm.n*tm.n)*log(tm.lambda_alpha)) - ((tm.n/2)*log(det(C_1))) - (((tm.T+q-num_z)/2)*log(det(S)));
end;

marg_like = fix_exp(ml_k-mean(ml_k));
prob_k = (1/sum(marg_like))*marg_like;

%
% end of bayes_lagorder.m
%
