function [duir,duir_std,buir,buir_std,abort] = dummy_impulses_fcn(mm,alpha,beta,Psi,Omega,Sigma_theta,waitbar)

buir = [];
buir_std = [];
abort = '';

if nargin<7;
   waitbar = 0;
end;
r = size(alpha,2);
if isempty(Sigma_theta)==1;
   %
   % compute the asymptotic covariance matrix for Psi and alpha.
   %
   % NOTE: It may indeed be empty!
   %
   if r>0;
      w = [mm.Z2;beta'*mm.Z1];
   else;
      w = mm.Z2;
   end;
   if isempty(w)==0;
      inv_ww = inverse(w*w');
      Sigma_theta = kron(inv_ww,Omega);
   end;
end;

%
% select only the relevant elements of Sigma_the
%
J_gamma = j_gamma(mm.n,mm.p,mm.pe,r,mm.d,mm.q1,mm.q0);
J_alpha = j_alpha(mm.n,mm.p,mm.pe,r,mm.d,mm.q1,mm.q0);
if mm.ad>0;
   J_phi = [zeros(mm.datad,mm.ad) eye(mm.datad)];
else;
   J_phi = eye(mm.datad);
end;
if size(J_alpha,2)>size(J_phi,2);
   J_phi = [J_phi zeros(mm.datad,size(J_alpha,2)-size(J_phi,2))];
end;
J_fix = [J_phi;J_gamma;J_alpha];
J_fix = kron(J_fix,eye(mm.n));
Sigma_theta = J_fix*Sigma_theta*J_fix';


%
% parameters on the dummy variables
%

phi_mat = Psi(:,mm.ad+1:mm.d);
duir = vec(phi_mat);

if r>0;
   Pi = alpha*beta(1:mm.n,:)';
else;
   Pi = zeros(mm.n,mm.n);
end;
if mm.p>=2;
   Phi = Psi(:,mm.d+1:mm.d+mm.n*(mm.p-1));
end;

ip = zeros(mm.p,mm.p);
for i=1:mm.p;
   for j=1:mm.p;
      if j>=i;
         ip(j,i)=1;
      end;
   end;
end;

%
% Computing levels VAR coefficients from
% VECM coefficients
%

ip = kron(ip,eye(mm.n));
J = eye(mm.n);
if mm.p>=2;
   M = [(Pi+eye(mm.n)) -Phi];
   M = M/ip;
   M = [M;[eye(mm.n*(mm.p-1)) zeros(mm.n*(mm.p-1),mm.n)]];
   J = [J zeros(mm.n,mm.n*(mm.p-1))];
else;
   M = (Pi+eye(mm.n))/ip;
end;

for i=1:mm.h;
   if i==1;
      M_i = M;
   else;
      M_i = M_i*M;
   end;
   B_i = J*M_i*J'*phi_mat;
   duir(:,i+1) = vec(B_i);
end;


if r>0;
   buir = kron(eye(mm.datad),beta(1:mm.n,:)')*duir;
end;

%
% now we look into the asymptotic standard errors
%

vcv = Sigma_theta(1:mm.n*mm.datad,1:mm.n*mm.datad);
duir_std = [sqrt(abs(diag(vcv))) zeros(mm.n*mm.datad,mm.h)];

if r>0;
   buir_vcv = kron(eye(mm.datad),beta(1:mm.n,:)')*vcv*kron(eye(mm.datad),beta(1:mm.n,:));
   buir_std = [sqrt(abs(diag(buir_vcv))) zeros(r*mm.datad,mm.h)];
end;

%
% Create the W matrix, needed to compute D_1
%

if mm.p>1;
   ip = inverse(ip);
   ip(1:mm.n,mm.n*(mm.p-1)+1:mm.n*mm.p) = eye(mm.n);
   ip(mm.n*(mm.p-1)+1:mm.n*mm.p,mm.n*(mm.p-1)+1:mm.n*mm.p) = zeros(mm.n,mm.n);
end;
if r>0;
   if mm.p==1;
      W = beta(1:mm.n,:);
   else;
      W = [[eye(mm.n*(mm.p-1)) zeros(mm.n*(mm.p-1),r)];[zeros(mm.n,mm.n*(mm.p-1)) beta(1:mm.n,:)]];
   end;
   W = ip*W;
else;
   if mm.p==1;
      W = [];   % need to remember this case
   else;
      W = [eye(mm.n*(mm.p-1));zeros(mm.n,mm.n*(mm.p-1))];
      W = ip*W;
   end;
end;

%
% handle the dynamics
%

if isempty(W)==0;
   %
   % set up a progress-bar if called for
   %
   if waitbar==1;
      curr_ini = find_inisettings;
      realscrsz = get(0,'ScreenSize');
      input_var.title = ['Progress for ' int2str(mm.h) ' dummy impulse responses'];
      input_var.facecolor = curr_ini.progress_facecolor;
      input_var.startfacecolor = curr_ini.progress_startfacecolor;
      input_var.edgecolor = curr_ini.progress_edgecolor;
      input_var.bgcolor = curr_ini.progress_bgcolor;
      input_var.label = 'Response number:';
      input_var.stop = 0;
      input_var.clock = 0;
      input_var.name = 'Dummy Impulse Response Functions';
      mywait = progressdlg(0,input_var);
%      set(mywait,'Name','Dummy Impulse Response Functions');
      set(mywait,'Color',get(0,'defaultuicontrolbackgroundcolor'));
      drawnow;
   end;
   %
   M_j = eye(mm.n*mm.p);
   for j=1:mm.h;
      if waitbar==1;
         if j==1;
            drawnow;
            progressdlg([(1/mm.h) 1]);
         else;
            abort = get(mywait,'UserData');
            if strcmp(abort,'cancel')==1;
               break;
            else;
               progressdlg([(j/mm.h) j]);
            end;
         end;
      end;
      %
      M_j = M_j*M;
      %
      % Computing the partials: D(2,j) = dvec(B_j)/dvec(phi_mat)'
      %
      D_2j = kron(eye(mm.datad),J*M_j*J');
      D_1j = zeros(mm.n*mm.datad,mm.n*(mm.n*(mm.p-1)+r));
      for i=0:j-1;
         if i==0;
            M_2 = eye(mm.n*mm.p);
         else;
            M_2 = M_2*M;
         end;
         M_1 = eye(mm.n*mm.p);
         for i1=1:j-1-i;
            M_1 = M_1*M';
         end;
         d_11 = phi_mat'*J*M_1*W;
         d_12 = J*M_2*J';
         %
         % Computing the partials D(1,j) = dvec(B_j)/dtheta' conditional on phi_mat
         %
         D_1j = D_1j+kron(d_11,d_12);
      end;
      D_j = [D_2j D_1j];
      duir_vcv = D_j*Sigma_theta*D_j';
      duir_std(:,j+1) = sqrt(abs(diag(duir_vcv)));
      if r>0;
         buir_vcv = kron(eye(mm.datad),beta(1:mm.n,:)')*duir_vcv*kron(eye(mm.datad),beta(1:mm.n,:));
         buir_std(:,j+1) = sqrt(abs(diag(buir_vcv)));
      end;
   end;
   %
   % delete the progress dialog if it was opened
   %
   if waitbar==1;
      set(mywait,'UserData','done');
      close(mywait);
      drawnow;
   end;
else;
   duir_std = duir_std(:,1)*ones(1,mm.h+1);
   if r>0;
      buir_std = buir_std(:,1)*ones(1,mm.h+1);
   end;
end;

%
% end of dummy_impulses_fcn.m
%
