function [prior_data,abort] = getpriordata(controls,cm,curr_ini,alpha_val,beta_val,omega_val,delta_val,gamma_val)

prior_data = [];
abort = '';

%
% draws from prior and presents into a structure containing the fields
%
%   beta
%   alpha
%   delta (if proper prior)
%   Gamma (if proper prior)
%   Omega
%   max_evalue
%
if cm.amat_type==1;
   if cm.amat_lag==1;
      A = cm.rank(cm.n+1).Omega;
   else;
      A = cm.amat_val;
   end;
   q = cm.n+2;
else;
   A = cm.lambda_a*eye(cm.n);
   q = cm.q_parm;
end;
D_mu = cm.prior.deter.mu;
D_sigma = cm.prior.deter.sigma;
G_mu = cm.prior.shortrun.mu;
G_sigma = cm.prior.shortrun.sigma;
if cm.cointvalue==1;
   %
   % cointegration analysis case
   %
   if get(controls.betarest,'Value')==0;
      %
      % no over-identifying restrictions
      %
      c_mat = cm.rank(cm.r+1).c_mat;
      c_mat_orth = cm.rank(cm.r+1).c_mat_orth;
      %
      input_var.title = ['Progress for ' num2str(cm.prior_draws,'%0.0f') ' draws'];
      input_var.facecolor = curr_ini.progress_facecolor;
      input_var.startfacecolor = curr_ini.progress_startfacecolor;
      input_var.edgecolor = curr_ini.progress_edgecolor;
      input_var.bgcolor = curr_ini.progress_bgcolor;
      input_var.stop = 0;
      input_var.clock = 1;
      input_var.label = 'Draw number:';
      input_var.name = ['Sampling From Prior - Rank ' num2str(cm.r,'%0.0f')];
      mywait = progressdlg(0,input_var);
      set(mywait,'Color',get(0,'defaultuicontrolbackgroundcolor'));
      drawnow;
      for draw=1:cm.prior_draws;
         %
         % Update progress dialog
         %
         abort = get(mywait,'UserData');
         if (strcmp(abort,'cancel')==1)|(strcmp(abort,'done')==1);
            break;
         else;
            progressdlg([draw/cm.prior_draws draw]);
         end;
         %
         % control the random number generator state
         %
         if curr_ini.random_state==2;
            randn('state',draw);
         elseif curr_ini.random_state==3;
            randn('state',sum(100*clock));
         elseif curr_ini.random_state==4;
            randn('state',sum(100*clock)+draw);
         end;
         %
         % Draw from Omega prior
         %
         if omega_val==1;
            [inv_Omega,warn] = wish_rnd(inverse(A),q,curr_ini.symmetric);
            if warn>0;
               Omega = A;
            else;
               Omega = inverse(inv_Omega);
            end;
         else;
            Omega = [];
         end;
         %
         % Draw from beta prior and conditional alpha prior
         %
         if (cm.r>0)&(cm.r<cm.n);
            if beta_val==1;
               Psi = matrix_t_rnd(zeros(cm.n-cm.r,cm.r),c_mat_orth'*c_mat_orth,c_mat'*c_mat,0);
               beta = c_mat+(c_mat_orth*Psi);
            else;
               beta = [];
            end;
            if alpha_val==1;
               alpha_std = chol(kron(inverse(beta'*beta),(cm.lambda_alpha^2)*Omega))';
               v_alpha = alpha_std*randn(cm.n*cm.r,1);
               alpha = vecinv(v_alpha,cm.n);
            else;
               alpha = [];
            end;
         elseif cm.r==cm.n;
            if beta_val==1;
               beta = eye(cm.n);
            else;
               beta = [];
            end;
            if alpha_val==1;
               alpha_std = chol(kron(eye(cm.n),(cm.lambda_alpha^2)*Omega))';
               v_alpha = alpha_std*randn(cm.n*cm.n,1);
               alpha = vecinv(v_alpha,cm.n);
            else;
               alpha = [];
            end;
         else;
            beta = [];
            alpha = [];
         end;
         %
         % Draw from conditional delta prior
         %
         if delta_val==1;
            if isempty(D_sigma)==0;
               delta_std = chol(kron(D_sigma,Omega))';
               v_delta = D_mu+(delta_std*randn(cm.n*cm.d,1));
               delta = vecinv(v_delta,cm.n);
            else;
               delta = [];
            end;
         else;
            delta = [];
         end;
         %
         % Draw from conditional Gamma prior
         %
         if gamma_val==1;
            if isempty(G_sigma)==0;
               gamma_std = chol(kron(G_sigma,Omega))';
               v_gamma = G_mu+(gamma_std*randn(size(gamma_std,1),1));
               Gamma = vecinv(v_gamma,cm.n);
            else;
               Gamma = [];
            end;
         else;
            Gamma = [];
         end;
         %
         % compute the maximum largest eigenvalue of the companion matrix
         %
         if (alpha_val==1)&(beta_val==1)&(omega_val==1)&(gamma_val==1);
            if isempty(Gamma)==1;
               e_values = companionrest(alpha,[],beta,1,cm.n,0);
            else;
               e_values = companionrest(alpha,Gamma,beta,cm.p,cm.n,0);
            end;
            e_values = sort(abs(e_values));
            for i1=1:size(e_values,1);
               max_evalue = e_values(size(e_values,1)-i1+1,1);
               if strcmp(num2str(max_evalue,'%1.10f'),'1.0000000000')==0;
                  break;
               end;
            end;
         else;
            max_evalue = [];
         end;
         prior_data(draw).beta = beta;
         prior_data(draw).alpha = alpha;
         prior_data(draw).Omega = Omega;
         prior_data(draw).delta = delta;
         prior_data(draw).Gamma = Gamma;
         prior_data(draw).max_evalue = max_evalue;
      end;
      %
      % Close the progress dialog
      %
      set(mywait,'UserData','done');
      close(mywait);
      drawnow;
   else;
      %
      % possibly over-identifying restrictions
      %
      h_vec = cm.beta_rest.h_vec;
      H_mat = cm.beta_rest.H_mat;
      c_mat = vecinv(h_vec,cm.n);
      c_mat_orth = null(c_mat','r');
      if cm.beta_rest.tot_free>0;
         G_mat = kron(eye(cm.r),inverse(c_mat_orth'*c_mat_orth)*c_mat_orth')*H_mat;
      end;
      %
      input_var.title = ['Progress for ' num2str(cm.prior_draws,'%0.0f') ' draws'];
      input_var.facecolor = curr_ini.progress_facecolor;
      input_var.startfacecolor = curr_ini.progress_startfacecolor;
      input_var.edgecolor = curr_ini.progress_edgecolor;
      input_var.bgcolor = curr_ini.progress_bgcolor;
      input_var.stop = 0;
      input_var.clock = 1;
      input_var.label = 'Draw number:';
      input_var.name = 'Sampling From Prior - Beta Restrictions';
      mywait = progressdlg(0,input_var);
      set(mywait,'Color',get(0,'defaultuicontrolbackgroundcolor'));
      drawnow;
      for draw=1:cm.prior_draws;
         %
         % Update progress dialog
         %
         abort = get(mywait,'UserData');
         if (strcmp(abort,'cancel')==1)|(strcmp(abort,'done')==1);
            break;
         else;
            progressdlg([draw/cm.prior_draws draw]);
         end;
         %
         % control the random number generator state
         %
         if curr_ini.random_state==2;
            randn('state',draw);
         elseif curr_ini.random_state==3;
            randn('state',sum(100*clock));
         elseif curr_ini.random_state==4;
            randn('state',sum(100*clock)+draw);
         end;
         %
         % Draw from Omega prior
         %
         if omega_val==1;
            [inv_Omega,warn] = wish_rnd(inverse(A),q,curr_ini.symmetric);
            if warn>0;
               Omega = A;
            else;
               Omega = inverse(inv_Omega);
            end;
         else;
            Omega = [];
         end;
         %
         %
         % Draw from beta prior and conditional alpha prior
         %
         if beta_val==1;
            if cm.beta_rest.tot_free>0;
               Psi = matrix_t_rnd(zeros(cm.n-cm.r,cm.r),c_mat_orth'*c_mat_orth,c_mat'*c_mat,0);
               psi = inverse(G_mat'*G_mat)*G_mat'*vec(Psi);
               v_beta = h_vec+(H_mat*psi);
               beta = vecinv(v_beta,cm.n);
            else;
               beta = c_mat;
            end;
         else;
            beta = [];
         end;
         if alpha_val==1;
            alpha_std = chol(kron(inverse(beta'*beta),(cm.lambda_alpha^2)*Omega))';
            v_alpha = alpha_std*randn(cm.n*cm.r,1);
            alpha = vecinv(v_alpha,cm.n);
         else;
            alpha = [];
         end;
         %
         % Draw from conditional delta prior
         %
         if delta_val==1;
            if isempty(D_sigma)==0;
               delta_std = chol(kron(D_sigma,Omega))';
               v_delta = D_mu+(delta_std*randn(cm.n*cm.d,1));
               delta = vecinv(v_delta,cm.n);
            else;
               delta = [];
            end;
         else;
            delta = [];
         end;
         %
         % Draw from conditional Gamma prior
         %
         if gamma_val==1;
            if isempty(G_sigma)==0;
               gamma_std = chol(kron(G_sigma,Omega))';
               v_gamma = G_mu+(gamma_std*randn(size(gamma_std,1),1));
               Gamma = vecinv(v_gamma,cm.n);
            else;
               Gamma = [];
            end;
         else;
            Gamma = [];
         end;
         %
         % compute the maximum largest eigenvalue of the companion matrix
         %
         if (alpha_val==1)&(beta_val==1)&(omega_val==1)&(gamma_val==1);
            if isempty(Gamma)==1;
               e_values = companionrest(alpha,[],beta,1,cm.n,0);
            else;
               e_values = companionrest(alpha,Gamma,beta,cm.p,cm.n,0);
            end;
            e_values = sort(abs(e_values));
            for i1=1:size(e_values,1);
               max_evalue = e_values(size(e_values,1)-i1+1,1);
               if strcmp(num2str(max_evalue,'%1.10f'),'1.0000000000')==0;
                  break;
               end;
            end;
         else;
            max_value = [];
         end;
         prior_data(draw).beta = beta;
         prior_data(draw).alpha = alpha;
         prior_data(draw).Omega = Omega;
         prior_data(draw).delta = delta;
         prior_data(draw).Gamma = Gamma;
         prior_data(draw).max_evalue = max_evalue;
      end;
      %
      % Close the progress dialog
      %
      set(mywait,'UserData','done');
      close(mywait);
      drawnow;
   end;
else;
   %
   % no cointegration analysis case
   %
   
end;


%
% end of getpriordata.m
%
