function [lr_gir,lr_gir_std] = longrun_gir_fcn(alpha,beta,Psi,Omega,Sigma_theta,epsilon,Z1,Z2,p,d,B_0,Sigma_B0)

%
% estimate the long-run generalized impulse responses
%

if nargin<=10;
   B_0 = [];
   Sigma_B0 = [];
end;

[n T] = size(epsilon);

if isempty(beta)==0;
   r = size(alpha,2);
else;
   r = 0;
end;
if isempty(Sigma_theta)==1;
   %
   % compute the asymptotic covariance matrix for Psi and alpha.
   %
   % NOTE: It may indeed be empty!
   %
   if r>0;
      w = [Z2;beta'*Z1];
   else;
      w = Z2;
   end;
   if isempty(w)==0;
      inv_ww = inverse(w*w');
      Sigma_theta = kron(inv_ww,Omega);
   end;
end;

Dn = duplication(n);
Dnp = inverse(Dn'*Dn)*Dn';

%
% Compute the B matrix with initial generalized responses
%

Sigma = inverse(sqrt(diag(diag(Omega))));
B = Omega*Sigma;

%
% Compute the asymptotic covariance matrix of B
%

L_n = lmatrix(n);
if isempty(B_0)==1;
   dB_omega = (kron(Sigma,eye(n))-((1/2)*kron(eye(n),Omega)*L_n*Sigma*Sigma*Sigma*L_n'))*Dn;
   Sigma_omega = (2/T)*Dnp*kron(Omega,Omega)*Dnp';
   Sigma_B = dB_omega*Sigma_omega*dB_omega';
else;
   dB_omega = (kron(Sigma,eye(n))-((1/2)*kron(eye(n),Omega)*L_n*Sigma*Sigma*Sigma*L_n'));
   dOmega_B0 = 2*ncommutation(n)*kron(B_0,eye(n));
   Sigma_B = dB_omega*dOmega_B0*Sigma_B0*dOmega_B0'*dB_omega';
end;

%
% Compute the C matrix
%

if r<n;
   [C,Sigma_C,dC_theta,Sig_theta] = cmat(Psi,alpha,beta,epsilon,Z1,Z2,p,d,1,Sigma_theta);
else;
   [C,Sigma_C,dC_theta,Sig_theta] = cmat_stat(Psi,alpha,beta,epsilon,Z1,Z2,p,d,1,Sigma_theta);
end;

%
% compute point estimate of long-run generalized impulse responses
%

lr_gir = C*B;

%
% And the standard errors
%

b_i = kron(B',eye(n));
i_c = kron(eye(n),C);
Sigma_gir = (b_i*Sigma_C*b_i')+(i_c*Sigma_B*i_c');
lr_gir_std = vecinv(sqrt(abs(diag(Sigma_gir))),n);

%
% end of longrun_gir_fcn.m
%
