function print_bayes_beta(cm,curr_ini,out,LR,pval,marg_like,marg_prob,marg_drap_unrest,marg_drap_rest,stat_marglike)

prt_tex = ['%0.' num2str(curr_ini.decimals,'%0.0f') 'f'];
prt_val = ['%' num2str(6+curr_ini.decimals,'%0.0f') '.' num2str(curr_ini.decimals,'%0.0f') 'f'];
fout = fopen(cm.outputfile,'at');
if curr_ini.texoutputformat>=2;
   fprintf(fout,'\\ruler\n\n%%******************************************************************************\n\n');
   fprintf(fout,'\\subsection*{Analyses of Identified Cointegration Vectors} \n\n');
   fprintf(fout,'\\header{Summary statistics from the Gibbs sampler} \n\n');
   fprintf(fout,'\\begin{tabular}{ll}\n');
   fprintf(fout,'Total draws & %0.0f \\\\\n',out.gibbs.draws);
   fprintf(fout,'Burn-in draws & %0.0f \\\\\n',cm.burn_in);
   fprintf(fout,'Considered draws & %0.0f \\\\\n',out.gibbs.real_draws);
   fprintf(fout,'Total discarded draws & %0.0f \\\\\n',out.gibbs.discard_draws);
   fprintf(fout,'Discarded explosive draws & %0.0f \\\\\n',out.gibbs.discard_explosive_draws);
   fprintf(fout,'Draw saving frequency & %0.1f\\%% \\\\\n',100/cm.save_freq);
   fprintf(fout,'Saved draws & %0.0f \\\\\n',cm.save_draws);
   fprintf(fout,'\\end{tabular}\n\n');
   %
   % print hyperparameters of the prior distribution
   %
   fprintf(fout,'\\vspace*{3mm}\n\n\\header{Hyperparameters for Prior Distribution} \n\n');
   fprintf(fout,'\\begin{tabular}{ll}\n');
   if cm.prior_inf_shortrun==1;
      fprintf(fout,'Baseline shrinkage ($\\lambda_{b}$): & %0.4f \\\\\n',cm.lambda_b);
      fprintf(fout,'Lag length shrinkage ($\\lambda_{l}$): & %0.4f \\\\\n',cm.lambda_l);
      fprintf(fout,'Off-diagonal/correlation shrinkage ($\\lambda_{\\rho}$): & %0.4f \\\\\n',cm.lambda_theta);
      if cm.q1+cm.q0>0;
         fprintf(fout,'Exogeneity shrinkage ($\\lambda_{e}$): & %0.4f \\\\\n',cm.lambda_e);
      end;
   else;
      fprintf(fout,'\\multicolumn{2}{l}{Improper prior for short-run parameters} \\\\\n');
   end;
   if cm.prior_inf_deter==1;
      fprintf(fout,'Deterministic shrinkage ($\\lambda_{d}$): & %0.4f \\\\\n',cm.lambda_d);
   else;
      fprintf(fout,'\\multicolumn{2}{l}{Improper prior for parameters on deterministic variables} \\\\\n');
   end;
   if cm.prior_inf_alpha==1;
      fprintf(fout,'$\\alpha$ shrinkage ($\\lambda_{\\alpha}$): & %0.4f \\\\\n',cm.lambda_alpha);
   else;
      fprintf(fout,'\\multicolumn{2}{l}{Improper prior for parameters on cointegration relations} \\\\\n');
   end;
   if cm.prior_inf_omega==1;
      if cm.amat_type==1;
         fprintf(fout,'$\\Omega$ prior type: & ML estimate of $\\Omega$ for full rank model \\\\\n');
         if cm.amat_lag>1;
            fprintf(fout,' & with %0.0f lags as $A$ matrix \\\\\n',cm.use_lag);
            Omega = cm.amat_val;
         else;
            fprintf(fout,' & with %0.0f lags as $A$ matrix \\\\\n',cm.p);
            Omega = cm.rank(cm.n+1).Omega;
         end;
         q_df = cm.n+2;
      else;
         fprintf(fout,'$\\Omega$ prior type: & $A$ matrix shrinkage times identity \\\\\n');
         fprintf(fout,'$A$ matrix shrinkage ($\\lambda_{A}$): & %0.4f \\\\\n',cm.lambda_a);
         %
         q_df = cm.n+2;
         if cm.q_df>=2;
            new_df = round(((cm.q_df-1)/10)*cm.T);
            q_df = max(q_df,new_df);
         end;
      end;
      %
      fprintf(fout,'q parameter: & %0.0f \\\\\n',q_df);
   else;
      fprintf(fout,'\\multicolumn{2}{l}{Improper prior for residual covariance matrix} \\\\\n');
   end;
   fprintf(fout,'\\end{tabular}\n\n');
   if (cm.prior_inf_omega==1)&(cm.amat_type==1)&(cm.amat_lag>1);
      %
      % print the A matrix
      %
      prt_str = '%s & %0.6f';
      r_str = 'lr';
      for i=2:cm.n;
         prt_str = [prt_str ' & %0.6f'];
         r_str = [r_str 'r'];
      end;
      fprintf(fout,['\\begin{tabular}{' r_str '} \n']);
      fprintf(fout,['\\multicolumn{' num2str(cm.n+1,'%0.0f') '}{l}{A matrix:} \\\\\n']);
      fprintf(fout,['\\multicolumn{' num2str(cm.n+1,'%0.0f') '}{l}{ } \\\\\n']);
      for i=1:cm.n;
         fprintf(fout,[prt_str ' \\\\\n'],cm.myvars(i,:),Omega(i,:));
      end;
      fprintf(fout,'\\end{tabular}\n\n');
   end;
   %
   if cm.beta_rest.dfbeta>0;
      fprintf(fout,'\\vspace*{3mm}\n\n\\header{Testing the restrictions using a classical LR test} \n\n');
      fprintf(fout,'\\begin{tabular}{rr}');
      fprintf(fout,['LR(%0.0f) & ' prt_tex ' \\\\ \n'],cm.beta_rest.dfbeta,LR);
      fprintf(fout,['p-value & ' prt_tex ' \\\\ \n'],pval);
      fprintf(fout,'\\end{tabular}\n\n');
      fprintf(fout,'\\vspace*{3mm}\n\n\\header{Approximation of the Marginal Likelihood}\n\n');
      fprintf(fout,'\\begin{tabular}{crr}\n');
      fprintf(fout,'$\\beta$ model & $\\log P(\\mbox{\\rm Data} | \\beta \\hspace*{1mm} \\mbox{\\rm model})$ & $\\log P(\\beta \\hspace*{1mm} \\mbox{\\rm model} | \\mbox{\\rm Data})$ \\\\\n');
      fprintf(fout,['Exact Identification: & ' prt_tex ' & ' prt_tex ' \\\\\n'],marg_drap_unrest,marg_prob(1,1));
      fprintf(fout,['Over-Identification & ' prt_tex ' & ' prt_tex ' \\\\\n'],marg_drap_rest,marg_prob(2,1));
      fprintf(fout,'\\end{tabular}\n\n');
      fprintf(fout,'\\vspace*{2mm}\n\n\\noindent\n\\textbf{NOTE:} The marginal likelihoods are here approximated using equation (11) in Draper, D. (1995),\n      ``Assessment and Propagation of Model Uncertainty'', \\textit{Journal of the Royal Statistical Society B}, pp. 45-97.\n\n');
      if (cm.prior_inf_alpha==1)&(cm.prior_inf_omega==1);
         fprintf(fout,'\\vspace*{3mm}\\header{Computed Marginal Likelihood}\n\n');
         fprintf(fout,'\\begin{tabular}{rr}\n');
         if stat_marglike==0;
            fprintf(fout,['$\\log P(\\mbox{\\rm Data} | \\beta \\hspace*{1mm} \\mbox{\\rm model})$ & ' prt_tex ' \\\\ \n'],marg_like);
         else;
            fprintf(fout,'$\\log P(\\mbox{\\rm Data} | \\beta \\hspace*{1mm} \\mbox{\\rm model})$ & Unable to compute \\\\\n');
         end;
         fprintf(fout,'\\end{tabular}\n\n');
      end;
      fprintf(fout,'\\vspace*{3mm}\n\n\\header{Posterior Mode Properties}\n\n');
      fprintf(fout,'\\begin{tabular}{ll} \n');
      fprintf(fout,['Max absolute eigenvalue of companion matrix:  & ' prt_tex ' \\\\ \n'],out.posterior_mode.max_evalue);
      fprintf(fout,['Value of log prior density: & ' prt_tex ' \\\\ \n'],out.posterior_mode.log_prior);
      fprintf(fout,['Value of log data density: & ' prt_tex ' \\\\ \n'],out.posterior_mode.log_like);
      if (cm.prior_inf_alpha==1)&(cm.prior_inf_omega==1);
         if stat_marglike==0;
            fprintf(fout,['Value of log posterior density: & ' prt_tex ' \\\\ \n'],out.posterior_mode.log_post);
         else;
            fprintf(fout,'Value of log posterior density: & Unable to compute \\\\\n');
         end;
      end;
      fprintf(fout,'\\end{tabular}\n\n');
      fprintf(fout,'\\vspace*{3mm}\n\n\\header{Full Posterior Mode Estimates of $\\beta$}\n\n');
      myprintstr = '%0.0f';
      r_str = 'r';
      j = 2;
      while j<=size(out.posterior_mode.beta,1)+1;
         myprintstr = [myprintstr ' & ' prt_tex];
         r_str = [r_str 'r'];
         j = j+1;
      end;
      myprintstr = [myprintstr ' \\\\\n'];
      fprintf(fout,['\\begin{tabular}{' r_str '}\n']);
      fprintf(fout,['relation & ' strrep(strtrim([cm.evars ' ' cm.xvars1 ' ' cm.restvec]),' ',' & ') ' \\\\\n']);
      fprintf(fout,myprintstr,[(1:size(out.posterior_mode.beta,2))' out.posterior_mode.beta']');
      fprintf(fout,'\\end{tabular}\n\n');
      fprintf(fout,'\\vspace*{3mm}\n\n\\header{Full Posterior Median Estimates of $\\beta$}\n\n');
      fprintf(fout,['\\begin{tabular}{' r_str '}\n']);
      fprintf(fout,['relation & ' strrep(strtrim([cm.evars ' ' cm.xvars1 ' ' cm.restvec]),' ',' & ') ' \\\\\n']);
      fprintf(fout,myprintstr,[(1:size(out.posterior_median.beta,2))' out.posterior_median.beta']');
      fprintf(fout,'\\end{tabular}\n\n');
      fprintf(fout,'\\vspace*{3mm}\n\n\\header{Full Posterior Mean Estimates of $\\beta$}\n\n');
      fprintf(fout,['\\begin{tabular}{' r_str '}\n']);
      fprintf(fout,['relation & ' strrep(strtrim([cm.evars ' ' cm.xvars1 ' ' cm.restvec]),' ',' & ') ' \\\\\n']);
      fprintf(fout,myprintstr,[(1:size(out.posterior_mean.beta,2))' out.posterior_mean.beta']');
      fprintf(fout,'\\end{tabular}\n\n');
      fprintf(fout,'\\vspace*{3mm}\n\n\\header{%0.0f\\%% Confidence Bands for $\\beta$}\n\n',cm.cbs);
      fprintf(fout,['\\begin{tabular}{' r_str '}\n']);
      fprintf(fout,['\\multicolumn{' num2str(size(r_str,2),'%0.0f') '}{c}{Lower Bound:} \\\\\n']);
      fprintf(fout,['relation & ' strrep(strtrim([cm.evars ' ' cm.xvars1 ' ' cm.restvec]),' ',' & ') ' \\\\\n']);
      fprintf(fout,myprintstr,[(1:size(out.posterior_mean.beta,2))' out.confidence_bands.beta_lower']');
      fprintf(fout,['\\multicolumn{' num2str(size(r_str,2),'%0.0f') '}{c}{Upper Bound:} \\\\\n']);
      fprintf(fout,['relation & ' strrep(strtrim([cm.evars ' ' cm.xvars1 ' ' cm.restvec]),' ',' & ') ' \\\\\n']);
      fprintf(fout,myprintstr,[(1:size(out.posterior_mean.beta,2))' out.confidence_bands.beta_upper']');
      fprintf(fout,'\\end{tabular}\n\n');
      if isfield(out.posterior_median,'beta_n')==1;
         fprintf(fout,'\\vspace*{3mm}\n\n\\header{Partial Posterior Mode Estimates of $\\beta$}\n\n');
         fprintf(fout,['\\begin{tabular}{' r_str '}\n']);
         fprintf(fout,['relation & ' strrep(strtrim([cm.evars ' ' cm.xvars1 ' ' cm.restvec]),' ',' & ') ' \\\\\n']);
         fprintf(fout,myprintstr,[(1:size(out.posterior_mode.beta,2))' out.posterior_mode.beta']');
         fprintf(fout,'\\end{tabular}\n\n');
         fprintf(fout,'\\vspace*{3mm}\n\n\\header{Partial Posterior Median Estimates of $\\beta$}\n\n');
         fprintf(fout,['\\begin{tabular}{' r_str '}\n']);
         fprintf(fout,['relation & ' strrep(strtrim([cm.evars ' ' cm.xvars1 ' ' cm.restvec]),' ',' & ') ' \\\\\n']);
         fprintf(fout,myprintstr,[(1:size(out.posterior_median.beta_n,2))' out.posterior_median.beta_n']');
         fprintf(fout,'\\end{tabular}\n\n');
         fprintf(fout,'\\vspace*{3mm}\n\n\\header{Partial Posterior Mean Estimates of $\\beta$}\n\n');
         fprintf(fout,['\\begin{tabular}{' r_str '}\n']);
         fprintf(fout,['relation & ' strrep(strtrim([cm.evars ' ' cm.xvars1 ' ' cm.restvec]),' ',' & ') ' \\\\\n']);
         fprintf(fout,myprintstr,[(1:size(out.posterior_mean.beta_n,2))' out.posterior_mean.beta_n']');
         fprintf(fout,'\\end{tabular}\n\n');
         fprintf(fout,'\\vspace*{3mm}\n\n\\header{%0.0f\\%% Confidence Bands for $\\beta$}\n\n',cm.cbs);
         fprintf(fout,['\\begin{tabular}{' r_str '}\n']);
         fprintf(fout,['\\multicolumn{' num2str(size(r_str,2),'%0.0f') '}{c}{Lower Bound:} \\\\\n']);
         fprintf(fout,['relation & ' strrep(strtrim([cm.evars ' ' cm.xvars1 ' ' cm.restvec]),' ',' & ') ' \\\\\n']);
         fprintf(fout,myprintstr,[(1:size(out.posterior_mean.beta_n,2))' out.confidence_bands.beta_n_lower']');
         fprintf(fout,['\\multicolumn{' num2str(size(r_str,2),'%0.0f') '}{c}{Upper Bound:} \\\\\n']);
         fprintf(fout,['relation & ' strrep(strtrim([cm.evars ' ' cm.xvars1 ' ' cm.restvec]),' ',' & ') ' \\\\\n']);
         fprintf(fout,myprintstr,[(1:size(out.posterior_mean.beta_n,2))' out.confidence_bands.beta_n_upper']');
         fprintf(fout,'\\end{tabular}\n\n');
      end;
   else;
      fprintf(fout,'\\vspace*{3mm}\n\n\\header{Approximation of the Marginal Likelihood}\n\n');
      fprintf(fout,'\\begin{tabular}{cr}\n');
      fprintf(fout,'$\\beta$ model & $\\log P(\\mbox{\\rm Data} | \\beta \\hspace*{1mm} \\mbox{\\rm model})$ \\\\\n');
      fprintf(fout,['Exact Identification: & ' prt_tex ' \\\\ \n'],marg_drap_unrest);
      fprintf(fout,'\\end{tabular}\n\n');
      fprintf(fout,'\\vspace*{2mm}\n\n\\noindent\n\\textbf{NOTE:} The marginal likelihood is here approximated using equation (11) in Draper, D. (1995),\n      ``Assessment and Propagation of Model Uncertainty'', \\textit{Journal of the Royal Statistical Society B}, pp. 45-97.\n\n');
      if (cm.prior_inf_alpha==1)&(cm.prior_inf_omega==1);
         fprintf(fout,'\\vspace*{3mm}\\header{Computed Marginal Likelihood}\n\n');
         fprintf(fout,'\\begin{tabular}{rr}\n');
         fprintf(fout,['$\\log P(\\mbox{\\rm Data} | \\beta \\hspace*{1mm} \\mbox{\\rm model})$ & ' prt_tex ' \\\\ \n'],marg_like);
         fprintf(fout,'\\end{tabular}\n\n');
      end;
      fprintf(fout,'\\vspace*{3mm}\n\n\\header{Posterior Mode Properties}\n\n');
      fprintf(fout,'\\begin{tabular}{ll} \n');
      fprintf(fout,['Max absolute eigenvalue of companion matrix:  & ' prt_tex ' \\\\ \n'],out.posterior_mode.max_evalue);
      fprintf(fout,['Value of log prior density: & ' prt_tex ' \\\\ \n'],out.posterior_mode.log_prior);
      fprintf(fout,['Value of log data density: & ' prt_tex ' \\\\ \n'],out.posterior_mode.log_like);
      if (cm.prior_inf_alpha==1)&(cm.prior_inf_omega==1);
         fprintf(fout,['Value of log posterior density: & ' prt_tex ' \\\\ \n'],out.posterior_mode.log_post);
      end;
      fprintf(fout,'\\end{tabular}\n\n');
      fprintf(fout,'\\vspace*{3mm}\n\n\\header{Full Posterior Mode Estimates of $\\beta$}\n\n');
      myprintstr = '%0.0f';
      r_str = 'r';
      j = 2;
      while j<=size(out.posterior_mode.beta,1)+1;
         myprintstr = [myprintstr ' & ' prt_tex];
         r_str = [r_str 'r'];
         j = j+1;
      end;
      myprintstr = [myprintstr ' \\\\\n'];
      fprintf(fout,['\\begin{tabular}{' r_str '}\n']);
      fprintf(fout,['relation & ' strrep(strtrim([cm.evars ' ' cm.xvars1 ' ' cm.restvec]),' ',' & ') ' \\\\\n']);
      fprintf(fout,myprintstr,[(1:size(out.posterior_mode.beta,2))' out.posterior_mode.beta']');
      fprintf(fout,'\\end{tabular}\n\n');
      fprintf(fout,'\\vspace*{3mm}\n\n\\header{Full Posterior Median Estimates of $\\beta$}\n\n');
      fprintf(fout,['\\begin{tabular}{' r_str '}\n']);
      fprintf(fout,['relation & ' strrep(strtrim([cm.evars ' ' cm.xvars1 ' ' cm.restvec]),' ',' & ') ' \\\\\n']);
      fprintf(fout,myprintstr,[(1:size(out.posterior_median.beta,2))' out.posterior_median.beta']');
      fprintf(fout,'\\end{tabular}\n\n');
      fprintf(fout,'\\vspace*{3mm}\n\n\\header{Posterior Mean Cointegration Space Estimator}\n\n');
      fprintf(fout,['\\begin{tabular}{' r_str '}\n']);
      fprintf(fout,['relation & ' strrep(strtrim([cm.evars ' ' cm.xvars1 ' ' cm.restvec]),' ',' & ') ' \\\\\n']);
      fprintf(fout,myprintstr,[(1:size(out.posterior_mode.beta,2))' out.pmcs.beta']');
      fprintf(fout,'\\end{tabular}\n\n');
      fprintf(fout,['\\noindent\nwith projective Frobenius span variation: ' prt_tex ' \n\n'],sqrt(out.pmcs.variation));
      fprintf(fout,'\\noindent\nNormalized $\\beta$ based on the Identifying Restrictions:\n\n');
      %
      beta = fix_norm_beta(out.pmcs.beta,cm);
      fprintf(fout,['\\begin{tabular}{' r_str '}\n']);
      fprintf(fout,['relation & ' strrep(strtrim([cm.evars ' ' cm.xvars1 ' ' cm.restvec]),' ',' & ') ' \\\\\n']);
      fprintf(fout,myprintstr,[(1:size(out.posterior_mode.beta,2))' beta']');
      fprintf(fout,'\\end{tabular}\n\n');
      fprintf(fout,'\\vspace*{3mm}\n\n\\header{%0.0f\\%% Confidence Bands for $\\beta$}\n\n',cm.cbs);
      fprintf(fout,['\\begin{tabular}{' r_str '}\n']);
      fprintf(fout,['\\multicolumn{' num2str(size(r_str,2),'%0.0f') '}{c}{Lower Bound:} \\\\\n']);
      fprintf(fout,['relation & ' strrep(strtrim([cm.evars ' ' cm.xvars1 ' ' cm.restvec]),' ',' & ') ' \\\\\n']);
      fprintf(fout,myprintstr,[(1:size(out.posterior_mode.beta,2))' out.confidence_bands.beta_lower']');
      fprintf(fout,['\\multicolumn{' num2str(size(r_str,2),'%0.0f') '}{c}{Upper Bound:} \\\\\n']);
      fprintf(fout,['relation & ' strrep(strtrim([cm.evars ' ' cm.xvars1 ' ' cm.restvec]),' ',' & ') ' \\\\\n']);
      fprintf(fout,myprintstr,[(1:size(out.posterior_mode.beta,2))' out.confidence_bands.beta_upper']');
      fprintf(fout,'\\end{tabular}\n\n');
      %
      if isfield(out.posterior_median,'beta_n')==1;
         fprintf(fout,'\\vspace*{3mm}\n\n\\header{Partial Posterior Mode Estimates of $\\beta$}\n\n');
         fprintf(fout,['\\begin{tabular}{' r_str '}\n']);
         fprintf(fout,['relation & ' strrep(strtrim([cm.evars ' ' cm.xvars1 ' ' cm.restvec]),' ',' & ') ' \\\\\n']);
         fprintf(fout,myprintstr,[(1:size(out.posterior_mode.beta,2))' out.posterior_mode.beta']');
         fprintf(fout,'\\end{tabular}\n\n');
         fprintf(fout,'\\vspace*{3mm}\n\n\\header{Partial Posterior Median Estimates of $\\beta$}\n\n');
         fprintf(fout,['\\begin{tabular}{' r_str '}\n']);
         fprintf(fout,['relation & ' strrep(strtrim([cm.evars ' ' cm.xvars1 ' ' cm.restvec]),' ',' & ') ' \\\\\n']);
         fprintf(fout,myprintstr,[(1:size(out.posterior_median.beta_n,2))' out.posterior_median.beta_n']');
         fprintf(fout,'\\end{tabular}\n\n');
         fprintf(fout,'\\vspace*{3mm}\n\n\\header{Partial Posterior Mean Cointegration Space Estimator}\n\n');
         fprintf(fout,['\\begin{tabular}{' r_str '}\n']);
         fprintf(fout,['relation & ' strrep(strtrim([cm.evars ' ' cm.xvars1 ' ' cm.restvec]),' ',' & ') ' \\\\\n']);
         fprintf(fout,myprintstr,[(1:size(out.posterior_mode.beta,2))' out.pmcs.beta_n']');
         fprintf(fout,'\\end{tabular}\n\n');
         fprintf(fout,['\\noindent\nwith projective Frobenius span variation: ' prt_tex ' \n\n'],sqrt(out.pmcs.variation_n));
         fprintf(fout,'\\noindent\nNormalized $\\beta$ based on the Identifying Restrictions:\n\n');
         %
         beta = fix_norm_beta(out.pmcs.beta_n,cm);
         fprintf(fout,['\\begin{tabular}{' r_str '}\n']);
         fprintf(fout,['relation & ' strrep(strtrim([cm.evars ' ' cm.xvars1 ' ' cm.restvec]),' ',' & ') ' \\\\\n']);
         fprintf(fout,myprintstr,[(1:size(out.posterior_mode.beta,2))' beta']');
         fprintf(fout,'\\end{tabular}\n\n');
         fprintf(fout,'\\vspace*{3mm}\n\n\\header{%0.0f\\%% Confidence Bands for $\\beta$}\n\n',cm.cbs);
         fprintf(fout,['\\begin{tabular}{' r_str '}\n']);
         fprintf(fout,['\\multicolumn{' num2str(size(r_str,2),'%0.0f') '}{c}{Lower Bound:} \\\\\n']);
         fprintf(fout,['relation & ' strrep(strtrim([cm.evars ' ' cm.xvars1 ' ' cm.restvec]),' ',' & ') ' \\\\\n']);
         fprintf(fout,myprintstr,[(1:size(out.posterior_mode.beta,2))' out.confidence_bands.beta_n_lower']');
         fprintf(fout,['\\multicolumn{' num2str(size(r_str,2),'%0.0f') '}{c}{Upper Bound:} \\\\\n']);
         fprintf(fout,['relation & ' strrep(strtrim([cm.evars ' ' cm.xvars1 ' ' cm.restvec]),' ',' & ') ' \\\\\n']);
         fprintf(fout,myprintstr,[(1:size(out.posterior_mode.beta,2))' out.confidence_bands.beta_n_upper']');
         fprintf(fout,'\\end{tabular}\n\n');
      end;
   end;
   %
   % Print other stuff
   %
   
else;
   fprintf(fout,'*******************************************************************************\n\n');
   fprintf(fout,'   Analyses of Identified Cointegration Vectors\n   ============================================\n\n');
   fprintf(fout,['Summary statistics from the Gibbs sampler\n~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~\n\n    Total draws:               ' num2str(out.gibbs.draws,'%8.0f') '\n    Burn-in draws:             ' num2str(cm.burn_in,'%8.0f') '\n    Considered draws:          ' num2str(out.gibbs.real_draws,'%8.0f') '\n    Total discarded draws:     ' num2str(out.gibbs.discard_draws,'%8.0f') '\n    Discarded explosive draws: ' num2str(out.gibbs.discard_explosive_draws,'%8.0f') '\n    Draw saving frequency:     ' num2str(100/cm.save_freq,'%5.1f') '%% \n    Saved draws:               ' num2str(cm.save_draws,'%8.0f') '\n\n']);
   %
   % print hyperparameters of the prior distribution
   %
   fprintf(fout,'Hyperparameters for Prior Distribution\n~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~\n\n');
   if cm.prior_inf_shortrun==1;
      fprintf(fout,'Baseline shrinkage:                      %0.4f \n',cm.lambda_b);
      fprintf(fout,'Lag length shrinkage:                    %0.4f \n',cm.lambda_l);
      fprintf(fout,'Off-diagonal/correlation shrinkage:      %0.4f \n',cm.lambda_theta);
      if cm.q1+cm.q0>0;
         fprintf(fout,'Exogeneity shrinkage:                    %0.4f \n',cm.lambda_e);
      end;
   else;
      fprintf(fout,'Improper prior for short-run parameters \n');
   end;
   if cm.prior_inf_deter==1;
      fprintf(fout,'Deterministic shrinkage:                 %0.4f \n',cm.lambda_d);
   else;
      fprintf(fout,'Improper prior for parameters on deterministic variables \n');
   end;
   if cm.prior_inf_alpha==1;
      fprintf(fout,'Alpha shrinkage:                         %0.4f \n',cm.lambda_alpha);
   else;
      fprintf(fout,'Improper prior for parameters on cointegration relations \n');
   end;
   if cm.prior_inf_omega==1;
      if cm.amat_type==1;
         fprintf(fout,'Omega prior type:                        ML estimate of Omega for full rank model \n');
         if cm.amat_lag>1;
            fprintf(fout,'                                         with %0.0f lags as A matrix \n\n',cm.use_lag);
            Omega = cm.amat_val;
         else;
            fprintf(fout,'                                         with %0.0f lags as A matrix \n\n',cm.p);
            Omega = cm.rank(cm.n+1).Omega;
         end;
         %
         % print the A matrix
         %
         prt_str = '%s   %12.6f';
         for i=2:cm.n;
            prt_str = [prt_str '   %12.6f'];
         end;
         for i=1:cm.n;
            fprintf(fout,[prt_str ' \n'],cm.myvars(i,:),Omega(i,:));
         end;
         fprintf(fout,'\n');
         q_df = cm.n+2;
      else;
         fprintf(fout,'Omega prior type:                        A matrix shrinkage times identity \n');
         fprintf(fout,'A matrix shrinkage:                      %0.4f \n',cm.lambda_a);
         %
         q_df = cm.n+2;
         if cm.q_df>=2;
            new_df = round(((cm.q_df-1)/10)*cm.T);
            q_df = max(q_df,new_df);
         end;
      end;
      %
      fprintf(fout,'q parameter:                             %0.0f \n\n',q_df);
   else;
      fprintf(fout,'Improper prior for residual covariance matrix \n\n');
   end;
   %
   if cm.beta_rest.dfbeta>0;
      fprintf(fout,'Testing the restrictions using a classical LR test\n~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~\n\n');
      fprintf(fout,['LR(%0.0f) = ' prt_val ' \n'],cm.beta_rest.dfbeta,LR);
      fprintf(fout,['p-value = ' prt_val ' \n\n'],pval);
      fprintf(fout,'Approximation of the Marginal Likelihood\n~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~\n\n');
      fprintf(fout,['Exact Identification: log P(Data|beta model) = ' prt_val ' --> P(beta model|Data) = ' prt_val ' \n'],marg_drap_unrest,marg_prob(1,1));
      fprintf(fout,['Over-Identification:  log P(Data|beta model) = ' prt_val ' --> P(beta model|Data) = ' prt_val ' \n\n'],marg_drap_rest,marg_prob(2,1));
      fprintf(fout,'where the two beta models have been given the same prior probability, P(beta model) = 1/2\n\n');
      fprintf(fout,'NOTE: The marginal likelihoods are here approximated using equation (11) in Draper, D. (1995),\n      "Assessment and Propagation of Model Uncertainty", Journal of the Royal Statistical Society B, pp. 45-97.\n\n');
      if (cm.prior_inf_alpha==1)&(cm.prior_inf_omega==1);
         fprintf(fout,'Computed Marginal Likelihood\n~~~~~~~~~~~~~~~~~~~~~~~~~~~~\n\n');
         if stat_marglike==0;
            fprintf(fout,['log P(Data|beta model) = ' prt_val ' \n\n'],marg_like);
         else;
            fprintf(fout,'log P(Data|beta model) = Unable to compute \n\n');
         end;
      end;
      %
      % Deal with some posterior mode features
      %
      fprintf(fout,'Posterior Mode Properties\n~~~~~~~~~~~~~~~~~~~~~~~~~\n\n');
      fprintf(fout,['Max absolute eigenvalue of companion matrix: ' prt_val ' \n'],out.posterior_mode.max_evalue);
      fprintf(fout,['Value of log prior density:                  ' prt_val ' \n'],out.posterior_mode.log_prior);
      fprintf(fout,['Value of log data density:                   ' prt_val ' \n'],out.posterior_mode.log_like);
      if (cm.prior_inf_alpha==1)&(cm.prior_inf_omega==1);
         if stat_marglike==0;
            fprintf(fout,['Value of log posterior density:              ' prt_val ' \n\n'],out.posterior_mode.log_post);
         else;
            fprintf(fout,'Value of log posterior density:              Unable to compute \n\n');
         end;
      else;
         fprintf(fout,'\n');
      end;
      fprintf(fout,'Full Posterior Mode Estimates of beta\n~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~\n\n');
      myprintstr = '%2.0f';
      j = 2;
      while j<=size(out.posterior_mean.beta,1)+1;
         myprintstr = [myprintstr ' ' prt_val];
         j = j+1;
      end;
      myprintstr = [myprintstr '\n'];
      fprintf(fout,myprintstr,[(1:size(out.posterior_mode.beta,2))' out.posterior_mode.beta']');
      %
      fprintf(fout,'\nFull Posterior Median Estimates of beta\n~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~\n\n');
      fprintf(fout,myprintstr,[(1:size(out.posterior_median.beta,2))' out.posterior_median.beta']');
      %
      fprintf(fout,'\nFull Posterior Mean Estimates of beta\n~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~\n\n');
      fprintf(fout,myprintstr,[(1:size(out.posterior_mean.beta,2))' out.posterior_mean.beta']');
      fprintf(fout,'\n');
      fprintf(fout,'%0.0f%% Confidence Bands for beta\n~~~~~~~~~~~~~~~~~~~~~~~~~~~~~\n\n',cm.cbs);
      fprintf(fout,'Lower Bound:\n');
      fprintf(fout,myprintstr,[(1:size(out.posterior_mean.beta,2))' out.confidence_bands.beta_lower']');
      fprintf(fout,'\nUpper Bound:\n');
      fprintf(fout,myprintstr,[(1:size(out.posterior_mean.beta,2))' out.confidence_bands.beta_upper']');
      fprintf(fout,'\n');
      if isfield(out.posterior_median,'beta_n')==1;
         fprintf(fout,'Partial Posterior Mode Estimates of beta\n~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~\n\n');
         fprintf(fout,myprintstr,[(1:size(out.posterior_mode.beta,2))' out.posterior_mode.beta']');
         %
         fprintf(fout,'\nPartial Posterior Median Estimates of beta\n~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~\n\n');
         fprintf(fout,myprintstr,[(1:size(out.posterior_median.beta,2))' out.posterior_median.beta_n']');
         %
         fprintf(fout,'\nPartial Posterior Mean Estimates of beta\n~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~\n\n');
         fprintf(fout,myprintstr,[(1:size(out.posterior_mean.beta,2))' out.posterior_mean.beta_n']');
         fprintf(fout,'\n');
         fprintf(fout,'%0.0f%% Confidence Bands for beta\n~~~~~~~~~~~~~~~~~~~~~~~~~~~~~\n\n',cm.cbs);
         fprintf(fout,'Lower Bound:\n');
         fprintf(fout,myprintstr,[(1:size(out.posterior_mean.beta,2))' out.confidence_bands.beta_n_lower']');
         fprintf(fout,'\nUpper Bound:\n');
         fprintf(fout,myprintstr,[(1:size(out.posterior_mean.beta,2))' out.confidence_bands.beta_n_upper']');
         fprintf(fout,'\n');
      end;
   else;
      fprintf(fout,'Approximation of the Marginal Likelihood\n~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~\n\n');
      fprintf(fout,['Exact Identification: log P(Data|beta model) = ' prt_val ' \n'],marg_drap_unrest);
      fprintf(fout,'NOTE: The marginal likelihood is here approximated using equation (11) in Draper, D. (1995),\n      "Assessment and Propagation of Model Uncertainty", Journal of the Royal Statistical Society B, pp. 45-97.\n\n');
      if (cm.prior_inf_alpha==1)&(cm.prior_inf_omega==1);
         fprintf(fout,'Computed Marginal Likelihood\n~~~~~~~~~~~~~~~~~~~~~~~~~~~~\n\n');
         fprintf(fout,['log P(Data|beta model) = ' prt_val ' \n\n'],marg_like);
      end;
      %
      % Deal with some posterior mode features
      %
      fprintf(fout,'Posterior Mode Properties\n~~~~~~~~~~~~~~~~~~~~~~~~~\n\n');
      fprintf(fout,['Max absolute eigenvalue of companion matrix: ' prt_val ' \n'],out.posterior_mode.max_evalue);
      fprintf(fout,['Value of log prior density:                  ' prt_val ' \n'],out.posterior_mode.log_prior);
      fprintf(fout,['Value of log data density:                   ' prt_val ' \n'],out.posterior_mode.log_like);
      if (cm.prior_inf_alpha==1)&(cm.prior_inf_omega==1);
         fprintf(fout,['Value of log posterior density:              ' prt_val ' \n\n'],out.posterior_mode.log_post);
      else;
         fprintf(fout,'\n');
      end;
      fprintf(fout,'Full Posterior Mode Estimates of beta\n~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~\n\n');
      myprintstr = '%2.0f';
      j = 2;
      while j<=size(out.posterior_mode.beta,1)+1;
         myprintstr = [myprintstr ' ' prt_val];
         j = j+1;
      end;
      myprintstr = [myprintstr '\n'];
      fprintf(fout,myprintstr,[(1:size(out.posterior_mode.beta,2))' out.posterior_mode.beta']');
      %
      fprintf(fout,'\nFull Posterior Median Estimates of beta\n~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~\n\n');
      fprintf(fout,myprintstr,[(1:size(out.posterior_median.beta,2))' out.posterior_median.beta']');
      %
      fprintf(fout,'\nPosterior Mean Cointegration Space Estimator\n~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~\n\n');
      fprintf(fout,myprintstr,[(1:size(out.pmcs.beta,2))' out.pmcs.beta']');
      fprintf(fout,['\nwith projective Frobenius span variation: ' prt_val ' \n\n'],sqrt(out.pmcs.variation));
      fprintf(fout,'Normalized based on the Identifying Restrictions:\n\n');
      %
      % Normaliza beta properly
      %
      beta = fix_norm_beta(out.pmcs.beta,cm);
      fprintf(fout,myprintstr,[(1:size(out.pmcs.beta,2))' beta']');
      fprintf(fout,'\n');
      fprintf(fout,'%0.0f%% Confidence Bands for beta\n~~~~~~~~~~~~~~~~~~~~~~~~~~~~~\n\n',cm.cbs);
      fprintf(fout,'Lower Bound:\n');
      fprintf(fout,myprintstr,[(1:size(out.posterior_mode.beta,2))' out.confidence_bands.beta_lower']');
      fprintf(fout,'\nUpper Bound:\n');
      fprintf(fout,myprintstr,[(1:size(out.posterior_mode.beta,2))' out.confidence_bands.beta_upper']');
      fprintf(fout,'\n');
      %
      if isfield(out.posterior_median,'beta_n')==1;
         fprintf(fout,'Partial Posterior Mode Estimates of beta\n~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~\n\n');
         fprintf(fout,myprintstr,[(1:size(out.posterior_mode.beta,2))' out.posterior_mode.beta']');
         %
         fprintf(fout,'\nPartial Posterior Median Estimates of beta\n~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~\n\n');
         fprintf(fout,myprintstr,[(1:size(out.posterior_median.beta,2))' out.posterior_median.beta_n']');
         %
         fprintf(fout,'\nPartial Posterior Mean Cointegration Space Estimator\n~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~\n\n');
         fprintf(fout,myprintstr,[(1:size(out.pmcs.beta,2))' out.pmcs.beta_n']');
         fprintf(fout,['\nwith projective Frobenius span variation: ' prt_val ' \n\n'],sqrt(out.pmcs.variation_n));
         fprintf(fout,'Normalized based on the Identifying Restrictions:\n\n');
         %
         % Normaliza beta properly
         %
         beta = fix_norm_beta(out.pmcs.beta_n,cm);
         fprintf(fout,myprintstr,[(1:size(out.pmcs.beta,2))' beta']');
         fprintf(fout,'\n');
         fprintf(fout,'%0.0f%% Confidence Bands for beta\n~~~~~~~~~~~~~~~~~~~~~~~~~~~~~\n\n',cm.cbs);
         fprintf(fout,'Lower Bound:\n');
         fprintf(fout,myprintstr,[(1:size(out.posterior_mode.beta,2))' out.confidence_bands.beta_n_lower']');
         fprintf(fout,'\nUpper Bound:\n');
         fprintf(fout,myprintstr,[(1:size(out.posterior_mode.beta,2))' out.confidence_bands.beta_n_upper']');
         fprintf(fout,'\n');
      end;
   end;
   %
   % Print other stuff
   %
   
end;
fclose(fout);

%
% end of print_bayes_beta.m
%
