function [d_mu,d_sigma,mu,sigma] = prior_minnesota(tm)

%
% constructs the mean and the covariance matrix for vec(Psi)
% for the levels VAR specification based on the tm structure containing the
% model descriptors
%

d_mu = [];
d_sigma = [];


if (tm.d>0)&(tm.prior_inf_deter==1);
   d_mu = 0*kron(ones(tm.d,1),tm.scale_n);
   d_sigma = (tm.lambda_d^2)*kron(eye(tm.d),diag(tm.scale_n .* tm.scale_n));
end;
%
% now we add the unit root mean
%

mu = [];
sigma = [];

if tm.prior_inf_shortrun==2;
   return;
end;

sigma = eye((size(tm.X1,1)-tm.d)*tm.n);
mu = zeros((size(tm.X1,1)-tm.d)*tm.n,1);

mu(1:(tm.n*tm.n),1) = vec(eye(tm.n));

%
% and now for the variances. lagged endogenous first
%

%
% scaling factors
%

scale_endo = kron((ones(tm.n,1)./tm.scale_n),tm.scale_n);
%
% dealing with lambda_theta
%
lambda_theta = eye(tm.n*tm.n);
if (tm.n>1)&(tm.lambda_theta~=1);
   lambda_theta = (tm.lambda_theta^2)*lambda_theta;
   for i=1:tm.n;
      for j=1:tm.n;
         if i==j;
            lambda_theta(j+(tm.n*(i-1)),j+(tm.n*(i-1))) = 1;
            break;
         end;
      end;
   end;
end;
lambda_theta = diag(lambda_theta);
num_pos = 0;
%
for k=1:tm.p;
   %
   % check if we should deal with seasonals
   %
   if (tm.lambda_s==0)|(tm.p<tm.s-1)|(tm.s==1);
      var_vec_k = ((tm.lambda_b^2)/(k^tm.lambda_l))*(lambda_theta .* scale_endo);
   else;
      %
      % deal with seasonal factors
      %
      if isint((k+1)/tm.s)==1;
         k_term = (k+1)/tm.s;
         sea_ind = 1;
      elseif isint(k/tm.s)==1;
         k_term = k/tm.s;
         sea_ind = 1;
      else;
         sea_ind = 0;
      end;
      if sea_ind==0;
         var_vec_k = ((tm.lambda_b^2)/(k^tm.lambda_l))*(lambda_theta .* scale_endo);
      else;
         var_vec_k = (((tm.lambda_b^2)*(tm.lambda_s^2))/(k_term^tm.lambda_l))*(lambda_theta .* scale_endo);
      end;
   end;
   %
   % select the correct positions for sigma
   %
   pos = [num_pos+1 num_pos+(tm.n*tm.n)];
   num_pos = num_pos+(tm.n*tm.n);
   sigma(pos(1):pos(2),pos(1):pos(2)) = diag(var_vec_k);
end;

%
% exogenous I(1) variables
%

if tm.q1>0;
   scale_exo1 = kron((ones(tm.q1,1)./tm.scale_q1),tm.scale_n);
   %
   % deal with k=0
   %
   var_vec_k = (tm.lambda_e^2)*(tm.lambda_b^2)*(tm.lambda_theta^2)*scale_exo1;
   pos = [num_pos+1 num_pos+(tm.n*tm.q1)];
   num_pos = num_pos+(tm.n*tm.q1);
   sigma(pos(1):pos(2),pos(1):pos(2)) = diag(var_vec_k);
   for k=1:tm.pe;
      if (tm.lambda_s==0)|(tm.pe<tm.s-1)|(tm.s==1);
         var_vec_k = (((tm.lambda_e^4)*(tm.lambda_b^2)*(tm.lambda_theta^2))/(k^tm.lambda_l))*scale_exo1;
      else;
         %
         % deal with seasonal factors
         %
         if isint((k+1)/tm.s)==1;
            k_term = (k+1)/tm.s;
            sea_ind = 1;
         elseif isint(k/tm.s)==1;
            k_term = k/tm.s;
            sea_ind = 1;
         else;
            sea_ind = 0;
         end;
         if sea_ind==0;
            var_vec_k = (((tm.lambda_e^4)*(tm.lambda_b^2)*(tm.lambda_theta^2))/(k^tm.lambda_l))*scale_exo1;
         else;
            var_vec_k = (((tm.lambda_e^4)*(tm.lambda_b^2)*(tm.lambda_theta^2)*(tm.lambda_s^2))/(k_term^tm.lambda_l))*scale_exo1;
         end;
      end;
      pos = [num_pos+1 num_pos+(tm.n*tm.q1)];
      num_pos = num_pos+(tm.n*tm.q1);
      sigma(pos(1):pos(2),pos(1):pos(2)) = diag(var_vec_k);
   end;
end;

if tm.q0>0;
   scale_exo0 = kron((ones(tm.q0,1)./tm.scale_q0),tm.scale_n);
   %
   % deal with k=0
   %
   var_vec_k = (tm.lambda_e^2)*(tm.lambda_b^2)*(tm.lambda_theta^2)*scale_exo0;
   pos = [num_pos+1 num_pos+(tm.n*tm.q0)];
   num_pos = num_pos+(tm.n*tm.q0);
   sigma(pos(1):pos(2),pos(1):pos(2)) = diag(var_vec_k);
   for k=1:tm.pe;
      if (tm.lambda_s==0)|(tm.pe<tm.s-1)|(tm.s==1);
         var_vec_k = (((tm.lambda_e^4)*(tm.lambda_b^2)*(tm.lambda_theta^2))/(k^tm.lambda_l))*scale_exo0;
      else;
         %
         % deal with seasonal factors
         %
         if isint((k+1)/tm.s)==1;
            k_term = (k+1)/tm.s;
            sea_ind = 1;
         elseif isint(k/tm.s)==1;
            k_term = k/tm.s;
            sea_ind = 1;
         else;
            sea_ind = 0;
         end;
         if sea_ind==0;
            var_vec_k = (((tm.lambda_e^4)*(tm.lambda_b^2)*(tm.lambda_theta^2))/(k^tm.lambda_l))*scale_exo0;
         else;
            var_vec_k = (((tm.lambda_e^4)*(tm.lambda_b^2)*(tm.lambda_theta^2)*(tm.lambda_s^2))/(k_term^tm.lambda_l))*scale_exo0;
         end;
      end;
      pos = [num_pos+1 num_pos+(tm.n*tm.q0)];
      num_pos = num_pos+(tm.n*tm.q0);
      sigma(pos(1):pos(2),pos(1):pos(2)) = diag(var_vec_k);
   end;
end;

%
% end of prior_minnesota.m
%
