function Pos = lscan(legh,ha,wdt,hgt,tol,stickytol,hl)
%LSCAN  Scan for good legend location.

debug = 0; % Set to 1 for debugging

if nargin==7 & hl>0,
  moved = DidLegendMove(legh);
  if moved, sticky = 1; else sticky = 0; end
else
  moved = 0;
end

% Calculate tile size
cap=get(ha,'Position'); % In Point coordinates
xlim=get(ha,'Xlim');
ylim=get(ha,'Ylim');
H=ylim(2)-ylim(1);
W=xlim(2)-xlim(1);

dh = 0.03*H;
dw = 0.03*W;
Hgt = hgt*H/cap(4);
Wdt = wdt*W/cap(3);
Thgt = H/max(1,floor(H/(Hgt+dh)));
Twdt = W/max(1,floor(W/(Wdt+dw)));
dh = (Thgt - Hgt)/2;
dw = (Twdt - Wdt)/2;

% Get data, points and text

Kids=get(ha,'children');
Xdata=[];Ydata=[];
for i=1:length(Kids),
  type = get(Kids(i),'type');
  if strcmp(type,'line')
    xk = get(Kids(i),'Xdata');
    yk = get(Kids(i),'Ydata');
    n = length(xk);
    if n < 100 & n > 1
      xk = interp1(xk,linspace(1,n,200));
      yk = interp1(yk,linspace(1,n,200));
    end
    Xdata=[Xdata,xk];
    Ydata=[Ydata,yk];
  elseif strcmp(type,'patch') | strcmp(type,'surface')
    xk = get(Kids(i),'Xdata');
    yk = get(Kids(i),'Ydata');
    Xdata=[Xdata,xk(:)'];
    Ydata=[Ydata,yk(:)'];
  elseif strcmp(get(Kids(i),'type'),'text'),
    tmpunits = get(Kids(i),'units');
    set(Kids(i),'units','data')
    tmp=get(Kids(i),'Position');
    ext=get(Kids(i),'Extent');
    set(Kids(i),'units',tmpunits);
    Xdata=[Xdata,[tmp(1) tmp(1)+ext(3)]];
    Ydata=[Ydata,[tmp(2) tmp(2)+ext(4)]];
  end
end
in = finite(Xdata) & finite(Ydata);
Xdata = Xdata(in);
Ydata = Ydata(in);

% Determine # of data points under each "tile"
xp = (0:Twdt:W-Twdt) + xlim(1);
yp = (0:Thgt:H-Thgt) + ylim(1);
wtol = Twdt / 100;
htol = Thgt / 100;
for j=1:length(yp)
  if debug, line([xlim(1) xlim(2)],[yp(j) yp(j)],'handlevisibility','off'); end
  for i=1:length(xp)
    if debug, line([xp(i) xp(i)],[ylim(1) ylim(2)],'handlevisibility','off'); end
    pop(j,i) = sum(sum((Xdata > xp(i)-wtol) & (Xdata < xp(i)+Twdt+wtol) & ...
                       (Ydata > yp(j)-htol) & (Ydata < yp(j)+Thgt+htol)));    
  end
end

if all(pop(:) == 0), pop(1) = 1; end

% Cover up fewest points.  After this while loop, pop will
% be lowest furthest away from the data
while any(pop(:) == 0)
  newpop = filter2(ones(3),pop);
  if all(newpop(:) ~= 0)
    break;
  end
  pop = newpop;
end
if debug, 
  figure, 
  surface('xdata',[xp xp(end)+Twdt],'ydata', [yp yp(end)+Thgt],...
          'zdata',zeros(length(yp)+1,length(xp)+1),...
          'cdata',pop)
  figure(gpf)
end
[j,i] = find(pop == min(pop(:)));
xp =  xp - xlim(1) + dw;
yp =  yp - ylim(1) + dh;
Pos = [cap(1)+xp(i(end))*cap(3)/W
       cap(2)+yp(j(end))*cap(4)/H];

%
% end of lscan.m
%
