%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                %
%          MatLab GUI dialog for showing yes/no dialog           %
%                                                                %
%          Function: query                                       %
%                                                                %
%          Input:                                                %
%                       mytext: text string                      %
%          		          myimage: image name                      %
%                       height: dialog height                    %
%                       mylabel: text string                     %
%                       width: dialog width                      %
%                       focus: yes or no (yes by default)        %
%                                                                %
%          Output:                                               %
%          		          answer: yes or no                        %
%                                                                %
%          This version:        May 18, 2006                     %
%          Written by: 	        Anders Warne                     %
%                               Copyright (c) 2001-2006          %
%                                                                %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function answer = query(mytext,myimage,height,mylabel,width,focus)

curr_ini = find_inisettings;

%#function closegui

if nargin==3;
   mylabel = 'Information';
end;
if nargin<5;
   width = 300;
end;

if width<250;
   width = 250;
end;

if nargin<6;
   focus = 'yes';
else;
   if ischar(focus)==1;
      focus = lower(focus);
      if (strcmp(focus,'yes')==0)&(strcmp(focus,'no')==0);
         focus = 'yes';
      end;
   else;
      focus = 'yes';
   end;
end;

mycons = getstoredimages;
if curr_ini.use_toolbar_bgcolor==1;
   bgcolor = (1/255)*(round(255*get(0,'defaultuicontrolbackgroundcolor'))-[8 4 8]);
   bgcolor(1) = max(0,bgcolor(1));
   bgcolor(2) = max(0,bgcolor(2));
   bgcolor(3) = max(0,bgcolor(3));
else;
   bgcolor = get(0,'defaultuicontrolbackgroundcolor');
end;
%
if strcmp(myimage,'information')==1;
   mylogo = mycons.information_image;
elseif strcmp(myimage,'question')==1;
   mylogo = mycons.question_image;
elseif strcmp(myimage,'warning')==1;
   mylogo = mycons.warning_image;
elseif strcmp(myimage,'error')==1;
   mylogo = mycons.error_image;
elseif strcmp(myimage,'exit')==1;
   mylogo = mycons.exit_image;
elseif strcmp(myimage,'delete')==1;
   mylogo = mycons.deletebig_image;
else;
   mylogo = mycons.logo_image;
end;
mylogo = maketrans(mylogo,[160 160 164],bgcolor);
mylogo = mirrorimage(mylogo);

scrsz = get(0,'ScreenSize');

textheight = height-54;
axesheight = (height-90)/2;
if axesheight<0;
   axesheight = 0;
   height = 90;
end;

querydlg = figure('Color',get(0,'defaultuicontrolbackgroundcolor'), ...
   'FileName','query.m', ...
   'MenuBar','none', ...
   'Units','pixels', ...
   'Position',[(scrsz(3)-width)/2 (scrsz(4)-height)/2 width height], ...
   'Tag','FigQuery', ...
   'Resize','off', ...
   'Visible','off', ...
   'Name',mylabel, ...
   'NumberTitle','off', ...
   'WindowStyle','modal', ...
   'CloseRequestFcn','closegui', ...
   'ToolBar','none');

if matlabnumber>=7.0;
   set(querydlg,'DockControl','off');
end;

imageaxes = axes('Units','pixels', ...
   'Box','on', ...
   'TickLength',[0 0], ...
   'CameraUpVector',[0 1 0], ...
   'Color',get(0,'defaultuicontrolbackgroundcolor'), ...
   'Position',[10 50+axesheight 39 39], ...
   'XTickLabelMode','manual', ...
   'YTickLabelMode','manual', ...
   'Tag','AxisLogo', ...
   'XColor',get(0,'defaultuicontrolbackgroundcolor'), ...
   'YColor',get(0,'defaultuicontrolbackgroundcolor'), ...
   'ZColor',get(0,'defaultuicontrolbackgroundcolor'));

image('CData',mylogo,'Clipping','off','Parent',imageaxes);

query_txt = uicontrol('Units','pixels', ...
   'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
   'Position',[50 50 width-63 textheight], ...
   'Style','text', ...
   'FontSize',curr_ini.gui_fontsize, ...
   'FontName',curr_ini.gui_fontname, ...
   'FontWeight',curr_ini.gui_fontweight, ...
   'FontAngle',curr_ini.gui_fontangle, ...
   'HorizontalAlignment','left', ...
   'String',' ', ...
   'Tag','Text');

%
% need to fix mytext string and turn it into a cell str
%
[out_str,npos] = textwrap(query_txt,cellstr(mytext));
set(query_txt,'String',out_str,'Position',[50 50 width-63 npos(4)]);
if max(size(out_str))==1;
   set(query_txt,'HorizontalAlignment','center');
end;

c_pos = 0;
if (60+npos(4)>=90)&(height>60+npos(4));
   %
   % fix the height of the dialog
   %
   set(querydlg,'Position',[(scrsz(3)-width)/2 (scrsz(4)-(60+npos(4)))/2 width 60+npos(4)]);
   c_pos = 60+npos(4);
elseif (60+npos(4)<90)&(height>60+npos(4));
   set(querydlg,'Position',[(scrsz(3)-width)/2 (scrsz(4)-90)/2 width 90]);
   c_pos = 90;
end;
if c_pos>0;
   axesheight = (c_pos-90)/2;
   set(imageaxes,'Position',[10 50+axesheight 39 39]);
end;



if strcmp(focus,'yes')==1;
   id_str = ' 2';
else;
   id_str = ' 1';
end;

myquery.yes = uicontrol('Units','pixels', ...
   'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
   'Position',[(width/2)-52.5 12 50 25], ...
   'String','Yes', ...
   'FontSize',curr_ini.gui_fontsize, ...
   'FontName',curr_ini.gui_fontname, ...
   'FontWeight',curr_ini.gui_fontweight, ...
   'FontAngle',curr_ini.gui_fontangle, ...
   'Enable','on', ...
   'Callback','closegui', ...
   'UserData','waiting', ...
   'Tag','YesButton');
myquery.no = uicontrol('Units','pixels', ...
   'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
   'Position',[(width/2)+2.5 12 50 25], ...
   'String','No', ...
   'FontSize',curr_ini.gui_fontsize, ...
   'FontName',curr_ini.gui_fontname, ...
   'FontWeight',curr_ini.gui_fontweight, ...
   'FontAngle',curr_ini.gui_fontangle, ...
   'Enable','on', ...
   'Callback','closegui', ...
   'Tag','NoButton');

set(querydlg,'UserData',myquery, ...
   'HandleVisibility','callback');

if (iswinnt==1)&(iscompiled==1)&(curr_ini.noicon==1);
   set(querydlg,'WindowStyle','normal');
   prog = ['bin\runwindow.exe ' fix_path([pwd '\bin\seticon.exe']) ' ' get(querydlg,'Name') ' NULL'];
   dos(prog);
   wait_fcn(curr_ini.delay);
   pos = get(querydlg,'Position');
   set(querydlg,'Position',[0 0 1 1]);
end;
%
set(querydlg,'Visible','on');
drawnow;
if (iswinnt==1)&(iscompiled==1);
   if curr_ini.noicon==1;
      drawnow;
      set(querydlg,'WindowStyle','modal');
      prog = ['bin\runwindow.exe ' fix_path([pwd '\bin\seticon.exe']) ' ' get(querydlg,'Name') ' NULL'];
      dos(prog);
      wait_fcn(curr_ini.delay);
      set(querydlg,'Position',pos);
   end;
   %
   drawnow;
   if matlabnumber<7;
      prog = ['bin\run_prog.exe ' fix_path([pwd '\bin\setfocus.exe']) ' ' get(querydlg,'Name') id_str];
      dos(prog);
      drawnow;
   else;
      if strcmp(strtrim(id_str),'2')==1;
         uicontrol(myquery.yes);
      else;
         uicontrol(myquery.no);
      end;
   end;
   if curr_ini.noicon==1;
      set(querydlg,'Position',pos);
   end;
elseif matlabnumber>=7;
   if strcmp(strtrim(id_str),'2')==1;
      uicontrol(myquery.yes);
   else;
      uicontrol(myquery.no);
   end;
end;

waitfor(querydlg,'waitstatus','inactive');
%uiwait(querydlg);

answer = get(get(querydlg,'CurrentObject'),'String');

if isempty(answer)==1;
   answer = 'No';
end;

delete(querydlg);
drawnow;

%
% end of query.m
%
