%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                %
%          MatLab GUI dialog for selecting weights on            %
%          different ranks                                       %
%                                                                %
%          Function: rank_weights                                %
%                                                                %
%          Input:                                                %
%                       selector: case switch function           %
%                       c_m: structure with model info           %
%                                                                %
%          Output:                                               %
%          	            h: handle to figure                      %
%                                                                %
%          This version:        May 17, 2006                     %
%          Written by:          Anders Warne                     %
%                               Copyright (c) 2001-2006          %
%                                                                %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function h = rank_weights(selector,c_m)

if strcmp(selector,'init')==1;
   thisexit = 0;
   tm = c_m;
   curr_ini = find_inisettings;
   height = 120+(25*tm.n);
else
   thisexit = 1;
   rw_dlg = findobj('Type','figure','Tag','RankWeightsDlg');
   rw = get(rw_dlg,'UserData');
   tm = get(rw.variables,'UserData');
end;

%
% Set screen size directly instead of using
% get(0,'ScreenSize')!
%

switch selector;
   case 'init';
      realscrsz = get(0,'ScreenSize');
      rw_dlg = figure('Color',get(0,'defaultuicontrolbackgroundcolor'), ...
         'FileName','rank_weights.m', ...
         'MenuBar','none', ...
         'PaperUnits','points', ...
         'Units','pixels', ...
         'Position',[(realscrsz(3)-400)/2 (realscrsz(4)-height)/2 400 height], ...
         'Tag','RankWeightsDlg', ...
         'Visible','off', ...
         'Resize','off', ...
         'Name','Prior Rank Probabilities', ...
         'NumberTitle','off', ...
         'CloseRequestFcn','rank_weights done', ...
         'ToolBar','none');

      if matlabnumber>=7.0;
         set(rw_dlg,'DockControl','off');
      end;

      %
      % Outer axis
      %

      bx_h = axesbox([2 2 398 height-10],'Select Weights for Prior Distribution',167,[0.5 1]);
      
      rw.variables = findobj(bx_h,'Type','uicontrol','Style','text','String','Select Weights for Prior Distribution');
      set(rw.variables,'UserData',tm);
      rw.icon = bx_h(1,1);

      rw.controls = [];
      for i=0:tm.n;

         uicontrol('Units','pixels', ...
            'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
            'Position',[20 70+(25*i) 180 20], ...
            'Style','text', ...
            'HorizontalAlignment','left', ...
            'FontSize',curr_ini.gui_fontsize, ...
            'FontName',curr_ini.gui_fontname, ...
            'FontWeight',curr_ini.gui_fontweight, ...
            'FontAngle',curr_ini.gui_fontangle, ...
            'String',['Absolute weight for r=' num2str(tm.n-i) ':'], ...
            'Tag','TextWeight');
   
         popup_h = uicontrol('Units','pixels', ...
            'BackgroundColor',[1 1 1], ...
            'Position',[280 70+(25*i) 100 20], ...
            'Style','popupmenu', ...
            'FontSize',curr_ini.gui_fontsize, ...
            'FontName',curr_ini.gui_fontname, ...
            'FontWeight',curr_ini.gui_fontweight, ...
            'FontAngle',curr_ini.gui_fontangle, ...
            'String','0|1|2|3|4|5|6|7|8|9|10', ...
            'Callback','rank_weights have_changed', ...
            'Value',2, ...
            'UserData',i+1, ...
            'HorizontalAlignment','center', ...
            'Tag','PopupWeight');
         rw.controls = [popup_h rw.controls];
         if (isfield(tm,'r_values')==1)&(size(tm.r_values,2)==tm.n+1);
            set(popup_h,'Value',tm.r_values(1,tm.n-i+1));
         end;
      end;

      %
      % Create graph button
      %

      rw.ok = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[80 20 90 20], ...
         'String','OK', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'CallBack','rank_weights check', ...
         'Enable','on', ...
         'UserData','working', ...
         'Tag','Done');

      %
      % Reset defaults button
      %
      
      rw.defaultsbutton = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[185 20 90 20], ...
         'String','Defaults', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'CallBack','rank_weights defaults', ...
         'Enable','off', ...
         'Tag','Defaults');

      %
      %  Done button
      %

      rw.cancel = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[290 20 90 20], ...
         'String','Cancel', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'CallBack','rank_weights done', ...
         'Enable','on', ...
         'UserData','waiting', ...
         'Tag','Done');

      set(rw_dlg,'UserData',rw,...
         'HandleVisibility','callback');

   case 'defaults'
      for i=0:tm.n;
         set(rw.controls(1,i+1),'Value',tm.r_values(1,tm.n-i+1));
      end;
      set(rw.defaultsbutton,'Enable','off');
   case 'have_changed'
      %
      % find the correct control
      %
      control_num = get(gcbo,'UserData');
      control_val = get(gcbo,'Value');
      if abs(tm.r_values(1,control_num)-control_val)>0;
         set(rw.defaultsbutton,'Enable','on');
      end;
   case 'check'
      %
      % check if the weights sum to zero
      %
      r_weights = zeros(1,tm.n+1);
      for i=1:size(rw.controls,2);
         r_weights(1,i) = get(rw.controls(1,i),'Value')-1;
      end;
      if sum(r_weights)>0;
         tm.r_weights = (1/sum(r_weights))*r_weights;
         tm.action = 'ok';
         set(rw.variables,'UserData',tm);
         rank_weights('done');
      else;
         txt = 'The absolute weights sum to zero. This is not allowed. Please make sure that at least one weight is greater than zero or press the Cancel button.';
         about(txt,'warning','Bad Weights',120,350);
      end;
   case 'done'
      if isfield(tm,'action')==0;
         tm.action = 'cancel';
      end;
      if isfield(tm,'r_weights')==0;
         tm.r_weights = [];
      end;
      set(rw.variables,'UserData',tm);
      set(rw.cancel,'UserData','done');
      set(rw.ok,'UserData','done');
end;

if thisexit==0;
   if (iswinnt==1)&(iscompiled==1)&(curr_ini.loadguiicon==1);
      prog = ['bin\runwindow.exe ' fix_path([pwd '\bin\seticon.exe']) ' ' get(rw_dlg,'Name') ' ' fix_filepath([pwd '\icons\prob-rank.ico'])];
      dos(prog);
      if (strcmp(curr_ini.pstoolsdir,'')==0)&(appexist([curr_ini.pstoolsdir 'pslist.exe'])==1);
         %
         % now we need to determine the pid
         %
         pid = getpid('seticon');
         set(rw.icon,'UserData',pid);
      end;
   end;
   %
   set(rw_dlg,'Visible','on');
   drawnow;
   if (iswinnt==1)&(iscompiled==1)&(matlabnumber<7);
      drawnow;
      prog = ['bin\run_prog.exe ' fix_path([pwd '\bin\setfocus.exe']) ' ' get(rw_dlg,'Name') ' 1'];
      dos(prog);
      drawnow;
   elseif matlabnumber>=7;
      uicontrol(rw.cancel);
   end;
   waitfor(rw.cancel,'UserData','done');
end;

if nargout==1;
   h = rw_dlg;
end;

%
% end of rank_weights.m
%
