%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                %
%          MatLab GUI dialog for selecting proportionality       %
%          and long-run restrictions on dummy variables,         %
%          estimate the model under the restrictions and test    %
%          if the data is consistent with the restrictions       %
%                                                                %
%          Function: restrict_dummies_dlg                        %
%                                                                %
%          Input:                                                %
%                       selector: case value string              %
%                       cm: current model structure              %
%                       curr_ini: var.ini settings               %
%                                                                %
%          Output:                                               %
%          	            None                                     %
%                                                                %
%          This version:        May 18, 2006                     %
%          Written by: 	        Anders Warne                     %
%                               Copyright (c) 2001-2006          %
%                                                                %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function cm = restrict_dummies_dlg(selector,cm,curr_ini)

if strcmp(selector,'init')==1;
   tm = cm;
   tm.num_const = tm.ad;
   tm.num_dummies = tm.datad;
   %
   tm.realscrsz = get(0,'ScreenSize');
   %
   dummy_names = vecstr(tm.deter);
   tm.dummy_names = dummy_names(1+tm.num_const:tm.num_dummies+tm.num_const,:);
   tm.ini = curr_ini;
   tm.realscrsz = get(0,'ScreenSize');
   c_rows = floor(sqrt(tm.num_dummies));
   check_width = 1;
   while check_width==1;
      c_cols = ceil(tm.num_dummies/c_rows);
      height = 125+(c_rows*20)+((c_rows-1)*5);
      width = 40+(150*c_cols)+(5*(c_cols-1));
      if width>tm.realscrsz(3);
         c_rows = c_rows+1;
      else;
         check_width = 0;
      end;
   end;
   if width<300;
      width = 300;
   end;
   width = 700;
   height = ((tm.num_dummies+1)*20)+(tm.num_dummies*5)+80+130;
else;
   pdd = findobj('Type','figure','Tag','RestrictDummiesDlg');
   pdd_graph = get(pdd,'UserData');
   tm = get(pdd_graph.estimate,'UserData');
   curr_ini = tm.ini;
end;

switch selector;
   case 'init';
      pdd = figure('Color',get(0,'defaultuicontrolbackgroundcolor'), ...
         'FileName','restrict_dummies_dlg.m', ...
         'MenuBar','none', ...
         'PaperUnits','points', ...
         'Units','pixels', ...
         'Position',[(tm.realscrsz(3)-width)/2 (tm.realscrsz(4)-height)/2 width height], ...
         'Tag','RestrictDummiesDlg', ...
         'Visible','off', ...
         'Resize','off', ...
         'Name','Restrictions on Deterministic Variables', ...
         'NumberTitle','off', ...
         'CloseRequestFcn','restrict_dummies_dlg done', ...
         'ToolBar','none');

      if matlabnumber>=7.0;
         set(pdd,'DockControl','off');
      end;

      axesbox([2 2 width-2 height-10],'Selection',45,[0.5 1]);

      %
      % GUI Header
      %

      mycons = getstoredimages;
      header_txt = 'Restrictions on Deterministics';
      desc_txt = 'Check mark the deterministic variables you wish to restrict, choose the type of restriction, and press the "Estimate" button to view the results. If you''re satisfied, then press the "Apply" button to make the restricted estimates valid for the "Dummy Impulse Responses". The "Continue" button will take you to the graphs of these these functions. The "Cancel" button returns you to the previous dialog.';
      pdd_graph.icon = dialog_header_fcn([16 height-109 width-30 85],mirrorimage(maketrans(mycons.deterrestbig_image,[160 160 164],[1 1 1])),header_txt,desc_txt);
      pdd_graph.icon = pdd_graph.icon(1,1);

      %
      % create the header text controls
      %
      
      uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[20 height-150 165 20], ...
         'Style','text', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight','bold', ...
         'HorizontalAlignment','left', ...
         'String','Variable', ...
         'Tag','VariableText');

      uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[185 height-150 165 20], ...
         'Style','text', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight','bold', ...
         'HorizontalAlignment','left', ...
         'String','Restrict', ...
         'Tag','RestrictText');

      uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[350 height-150 165 20], ...
         'Style','text', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight','bold', ...
         'HorizontalAlignment','left', ...
         'String','Long Run', ...
         'Tag','LongRunText');

      uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[515 height-150 165 20], ...
         'Style','text', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight','bold', ...
         'HorizontalAlignment','left', ...
         'String','Proportionality', ...
         'Tag','ProportionalityText');


      pdd_graph.var_controls = [];
      pdd_graph.rest_controls = [];
      pdd_graph.longrun_controls = [];
      pdd_graph.prop_controls = [];

      for i=1:tm.num_dummies;
         %
         % enter variable name
         %
         var_control = uicontrol('Units','pixels', ...
            'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
            'Position',[20 height-170-(25*(i-1)) 165 20], ...
            'Style','text', ...
            'FontSize',curr_ini.gui_fontsize, ...
            'FontName',curr_ini.gui_fontname, ...
            'FontWeight',curr_ini.gui_fontweight, ...
            'FontAngle',curr_ini.gui_fontangle, ...
            'HorizontalAlignment','left', ...
            'UserData',i, ...
            'String',strtrim(tm.dummy_names(i,:)), ...
            'Tag','NamesText');
         %
         rest_control = uicontrol('Units','pixels', ...
            'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
            'Position',[185 height-170-(25*(i-1)) 165 20], ...
            'FontSize',curr_ini.gui_fontsize, ...
            'FontName',curr_ini.gui_fontname, ...
            'FontWeight',curr_ini.gui_fontweight, ...
            'FontAngle',curr_ini.gui_fontangle, ...
            'Style','checkbox', ...
            'Value',0, ...
            'Enable','on', ...
            'Visible','on', ...
            'HorizontalAlignment','left', ...
            'Callback','restrict_dummies_dlg check_boxes', ...
            'UserData',i, ...
            'String','Yes', ...
            'Tag',strtrim(tm.dummy_names(i,:)));
         %
         longrun_control = uicontrol('Units','pixels', ...
            'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
            'Position',[350 height-170-(25*(i-1)) 165 20], ...
            'FontSize',curr_ini.gui_fontsize, ...
            'FontName',curr_ini.gui_fontname, ...
            'FontWeight',curr_ini.gui_fontweight, ...
            'FontAngle',curr_ini.gui_fontangle, ...
            'Style','radiobutton', ...
            'Value',0, ...
            'Enable','off', ...
            'Visible','on', ...
            'HorizontalAlignment','left', ...
            'UserData',i, ...
            'Callback','restrict_dummies_dlg radio_button', ...
            'String',['Apply to ' strtrim(tm.dummy_names(i,:))], ...
            'Tag','longrun');
         %
         prop_control = uicontrol('Units','pixels', ...
            'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
            'Position',[515 height-170-(25*(i-1)) 165 20], ...
            'FontSize',curr_ini.gui_fontsize, ...
            'FontName',curr_ini.gui_fontname, ...
            'FontWeight',curr_ini.gui_fontweight, ...
            'FontAngle',curr_ini.gui_fontangle, ...
            'Style','radiobutton', ...
            'Value',0, ...
            'Enable','off', ...
            'Visible','on', ...
            'HorizontalAlignment','left', ...
            'UserData',i, ...
            'Callback','restrict_dummies_dlg radio_button', ...
            'String',['Apply to ' strtrim(tm.dummy_names(i,:))], ...
            'Tag','prop');
         %
         pdd_graph.var_controls = [pdd_graph.var_controls var_control];
         pdd_graph.rest_controls = [pdd_graph.rest_controls rest_control];
         pdd_graph.longrun_controls = [pdd_graph.longrun_controls longrun_control];
         pdd_graph.prop_controls = [pdd_graph.prop_controls prop_control];
      end;
      
      %
      % Buttons for controling estimation
      %

      pdd_graph.save = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[width-300 45 90 20], ...
         'String','Save', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'CallBack','restrict_dummies_dlg save', ...
         'Enable','off', ...
         'Tag','Save');


      pdd_graph.restore = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[width-205 45 90 20], ...
         'String','Restore', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'CallBack','restrict_dummies_dlg restore', ...
         'Enable','off', ...
         'Tag','Restore');

      pdd_graph.estimate = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[width-110 45 90 20], ...
         'String','Estimate', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'CallBack','restrict_dummies_dlg estimate', ...
         'Enable','off', ...
         'UserData',tm, ...
         'Tag','Estimate');

      pdd_graph.done = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[width-300 20 90 20], ...
         'String','Continue', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'CallBack','restrict_dummies_dlg done', ...
         'Enable','on', ...
         'UserData','waiting', ...
         'Tag','Done');

      pdd_graph.cancel = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[width-205 20 90 20], ...
         'String','Cancel', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'CallBack','restrict_dummies_dlg done', ...
         'Enable','on', ...
         'Tag','Cancel');

      pdd_graph.apply = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[width-110 20 90 20], ...
         'String','Apply', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'CallBack','restrict_dummies_dlg apply', ...
         'Enable','off', ...
         'Tag','Apply');

      %
      % check if data har been stored for the controls
      %
      
      file = [tm.modelsdir 'dummy-ir-selection-' tm.modelfile '-' num2str(tm.n,'%0.0f') '.' num2str(tm.r,'%0.0f') '-' num2str(tm.num_dummies,'%0.0f') '.' num2str(tm.num_const,'%0.0f') '.mat'];
      if fileexist(file)==1;
         a = load(file);
         if (isfield(a,'dummies')==1)&(size(a.dummies,1)==size(pdd_graph.var_controls,2));
            for i=1:size(pdd_graph.rest_controls,2);
               set(pdd_graph.rest_controls(1,i),'Value',a.dummies(i,1));
               en_str = 'off';
               if a.dummies(i,1)==1;
                  en_str = 'on';
               end;
               if (tm.r<tm.n)&(tm.r>0);
                  set(pdd_graph.longrun_controls(1,i),'Value',a.dummies(i,2),'Enable',en_str);
               end;
               if tm.datad>1;
                  set(pdd_graph.prop_controls(1,i),'Value',a.dummies(i,3),'Enable',en_str);
               end;
               if sum(sum(a.dummies))>0;
                  set(pdd_graph.estimate,'Enable','on');
               end;
            end;
         end;
      end;

      set(pdd,'UserData',pdd_graph,...
         'HandleVisibility','callback');

   case 'estimate'
      set(pdd,'Visible','off');
      drawnow;
      %
      % determine the dummies to select
      %
      lr_dummies = [];
      prop_dummies = [];
      for i=1:size(pdd_graph.rest_controls,2);
         if get(pdd_graph.longrun_controls(1,i),'Value')==1;
            lr_dummies = [lr_dummies i];
         end;
         if get(pdd_graph.prop_controls(1,i),'Value')==1;
            prop_dummies = [prop_dummies i];
         end;
      end;
      if size(prop_dummies)<2;
         prop_dummies = [];
      end;
      if isempty(lr_dummies)==0;
         lr_dummy_names = tm.dummy_names(lr_dummies,:);
      else;
         lr_dummy_names = '';
      end;
      if isempty(prop_dummies)==0;
         prop_dummy_names = tm.dummy_names(prop_dummies,:);
      else;
         prop_dummy_names = '';
      end;
      if isempty([prop_dummies lr_dummies])==1;
         txt = 'The proportionality restrictions require that you''ve selected at least 2 deterministic variables.';
         about(txt,'information','Bad Restriction',120,350);
         set(pdd,'Visible','on');
         drawnow;
         return;
      end;
      %
      % if there are long-run restrictions create new Z2 matrix and prepare estimates conditional on the long-run
      % restrictions
      %
      abort = '';
      num_rest = 0;
      %
      my_rest = 0;
      if isempty(lr_dummies)==0;
         my_rest = (tm.n-tm.r)*size(lr_dummies,2);
      end;
      if isempty(prop_dummies)==0;
         my_rest = my_rest+((tm.n*size(prop_dummies,2))-(tm.n+size(prop_dummies,2)-1));
      end;
      setlogtext(['Estimating under ' num2str(my_rest,'%0.0f') ' restrictions on deterministics...']);
      %
      if isempty(lr_dummies)==0;
         %
         % show a wait dialog if using restrictions
         %
         if sum(tm.restrict)>0;
            sh_lr_dummies = strtrim(lr_dummy_names(1,:));
            for i=2:size(lr_dummy_names,1);
               sh_lr_dummies = [sh_lr_dummies ', ' strtrim(lr_dummy_names(i,:))];
            end;
            txt = strvcat(' ','Computing zero long-run estimates for dummy variables...',['Selected variables: ' sh_lr_dummies],'Please wait!');
            mywait = waitdlg(txt,'information');
            waitf = get(mywait,'UserData');
         end;
         [alpha,Psi,beta,Omega,epsilon,Sigma_theta,Psi_f] = estimate_longrun_dummies(tm.Z0,tm.Z1,tm.Z2,tm.num_const,lr_dummies,tm.r,tm.dcoint,tm.q1,tm.p,tm.pe,tm.d,tm.q0,tm.restrict,tm.modelsdir,tm.modelfile,curr_ini.reestbeta);
         %
         num_rest = (tm.n-tm.r)*size(lr_dummies,2);
         if isempty(prop_dummies)==1;
            %
            % compute the LR-test
            %
            test = 2*(loglike(tm.epsilon)-loglike(epsilon));
            if test<0;
               test = 0;
            end;
            if curr_ini.sscorrect==0;
               deg_free = num_rest;
               pval = 1-chis_cdf(test,deg_free);
            else;
               deg_free = [num_rest tm.T-tm.df+floor(num_rest/tm.n)-1];
               test = (deg_free(1,2)/(tm.T*deg_free(1,1)))*test;
               pval = 1-fdis_cdf(test,deg_free(1,2),deg_free(1,2));
            end;
            %
            % compute parameter values
            %
            d = tm.num_const+(tm.num_dummies-size(lr_dummies,2));
            if d>0;
               delta_1 = Psi(:,1:d);
               Phi = Psi(:,d+1:size(Psi,2));
            else;
               delta_1 = [];
               Phi = Psi;
            end;
            %
            rho = beta(tm.n+tm.q1+tm.dcoint+1:size(beta,1),:);
            beta = beta(1:tm.n+tm.q1+tm.dcoint,:);
            delta_2 = alpha*rho';
            dum_2 = tm.num_const+lr_dummies;
            dum_1 = setdiff((1:1:tm.d),dum_2);
            %
            delta = zeros(tm.n,tm.d);
            if isempty(dum_1)==0;
               for i=1:size(dum_1,2);
                  delta(:,dum_1(1,i)) = delta_1(:,i);
               end;
            end;
            if isempty(dum_2)==0;
               for i=1:size(dum_2,2);
                  delta(:,dum_2(1,i)) = delta_2(:,i);
               end;
            end;
            %
            % store parameter values
            %
            dm.Psi = [delta Phi];
            dm.alpha = alpha;
            dm.beta = beta;
            dm.Omega = (1/tm.T)*epsilon*epsilon';
            %
            % the asymptotic covariance matrix
            %
            q = size(Phi,2);
            H_mat = eye(tm.n*(q+tm.r+d));
            h_mat = kron(rho,eye(tm.n));
            h_mat = [zeros(size(h_mat,1),size(H_mat,2)-size(h_mat,2)) h_mat];
            if d>0;
               h2_mat = H_mat(1:tm.n*d,:);
               H_mat = H_mat((tm.n*d)+1:size(H_mat,1),:);
               %
               % resort h_mat and h2_mat
               %
               Help_mat = [];
               num_unrest = 1;
               num_rest = 1;
               for i=1:tm.d;
                  unrest = sum(i==dum_1);
                  if unrest==1;
                     low = 1+tm.n*(num_unrest-1);
                     up = tm.n*num_unrest;
                     num_unrest = num_unrest+1;
                     m_help = h2_mat(low:up,:);
                  else;
                     low = 1+tm.n*(num_rest-1);
                     up = tm.n*num_rest;
                     num_rest = num_rest+1;
                     m_help = h_mat(low:up,:);
                  end;
                  Help_mat = [Help_mat;m_help];
               end;
               H_mat = [Help_mat;H_mat];
            else;
               H_mat = [h_mat;H_mat];
            end;
            dm.Sigma_theta = H_mat*Sigma_theta*H_mat';
         end;
         %
         if sum(tm.restrict)>0;
            set(waitf.text,'UserData','done');
            delete(mywait);
            drawnow;
         end;
      else;
         %
         % locate estimated parameters
         %
         alpha = tm.alpha;
         Psi = tm.Psi;
         beta = tm.beta(:,1:tm.r);
         Omega = (1/tm.T)*tm.epsilon*tm.epsilon';
      end;
      %
      % check if we should estimate subject to proportionality restrictions
      %
      if isempty(prop_dummies)==0;
         %
         % prepare Z1 and Z2
         %
         if isempty(lr_dummies)==0;
            Z2_lrd = tm.Z2(lr_dummies+tm.num_const,:);
         else;
            Z2_lrd = [];
         end;
         D = tm.Z2(prop_dummies+tm.num_const,:);
         %
         all_z2 = (1:1:size(tm.Z2,1));
         use_z2 = setdiff(all_z2,sort([lr_dummies prop_dummies])+tm.num_const);
         if isempty(use_z2)==0;
            Z2_lr = tm.Z2(use_z2,:);
            %
            % pick out the correct entrie of Psi for the new Z2
            %
            if isempty(lr_dummies)==0;
               Psi = Psi_f(:,use_z2);
            else;
               Psi = Psi(:,use_z2);
            end;
         else;
            Z2_lr = [];
            Psi = [];
         end;
         Z1_lr = [tm.Z1;Z2_lrd];
         d = tm.num_const+(tm.num_dummies-size([lr_dummies prop_dummies],2));
         %
         % estimate under proportionality restrictions
         %
         [alpha,beta,Psi,phi,kappa,epsilon,info_mat,k_orth,abort] = estimate_proportionality(tm.Z0,Z1_lr,Z2_lr,D,tm.epsilon,tm.p,tm.pe,d,tm.q1,tm.q0,tm.dcoint+size(lr_dummies,2),alpha,beta,Psi,tm.modelsdir,tm.modelfile,curr_ini.convcrit,curr_ini.maxit,curr_ini.reestbeta,tm.restrict,1);
         %
         if strcmp(abort,'cancel')==0;
            %
            % computing the test
            %
            num_rest = num_rest+((tm.n*size(prop_dummies,2)) - (tm.n+size(prop_dummies,2)-1) );
            test = 2*(loglike(tm.epsilon)-loglike(epsilon));
            if test<0;
               test = 0;
            end;
            if curr_ini.sscorrect==0;
               deg_free = num_rest;
               pval = 1-chis_cdf(test,deg_free);
            else;
               deg_free = [num_rest tm.T-tm.df+floor(num_rest/tm.n)-1];
               test = (deg_free(1,2)/(tm.T*deg_free(1,1)))*test;
               pval = 1-fdis_cdf(test,deg_free(1,2),deg_free(1,2));
            end;
            %
            % fix all the parameters
            %
            if d>0;
               delta_1 = Psi(:,1:d);
               Phi = Psi(:,d+1:size(Psi,2));
            else;
               delta_1 = [];
               Phi = Psi;
            end;
            %
            if isempty(lr_dummies)==0;
               rho = beta(tm.n+tm.q1+tm.dcoint+1:size(beta,1),:);
               beta = beta(1:tm.n+tm.q1+tm.dcoint,:);
               delta_2 = alpha*rho';
               dum_2 = tm.num_const+lr_dummies;
            else;
               rho = [];
               delta_2 = [];
               dum_2 = [];
            end;
            delta_3 = phi*kappa';
            dum_3 = tm.num_const+prop_dummies;
            %
            dum_1 = setdiff((1:1:tm.d),[dum_2 dum_3]);
            %
            delta = zeros(tm.n,tm.d);
            if isempty(dum_1)==0;
               for i=1:size(dum_1,2);
                  delta(:,dum_1(1,i)) = delta_1(:,i);
               end;
            end;
            if isempty(dum_2)==0;
               for i=1:size(dum_2,2);
                  delta(:,dum_2(1,i)) = delta_2(:,i);
               end;
            end;
            for i=1:size(dum_3,2);
               delta(:,dum_3(1,i)) = delta_3(:,i);
            end;
            dm.Psi = [delta Phi];
            dm.alpha = alpha;
            dm.beta = beta;
            dm.Omega = (1/tm.T)*epsilon*epsilon';
            %
            % the asymptotic covariance matrix
            %
            q = size(Phi,2);
            H_mat = [zeros(tm.n*(q+tm.r+d),tm.n+size(k_orth,2)) eye(tm.n*(q+tm.r+d))];
            if d>0;
               h1_mat = H_mat(1:tm.n*d,:);
               H_mat = H_mat((tm.n*d)+1:size(H_mat,1),:);
            else;
               h1_mat = [];
            end;
            if isempty(dum_2)==0;
               h2_mat = kron(rho,eye(tm.n));
               h2_mat = [zeros(size(h2_mat,1),size(H_mat,2)-size(h2_mat,2)) h2_mat];
            else;
               h2_mat = [];
            end;
            h3_mat = [kron(kappa,eye(tm.n)) kron(k_orth,phi)];
            h3_mat = [h3_mat zeros(size(h3_mat,1),tm.n*(q+tm.r+d))];
            %
            Help_mat = [];
            num_1 = 1;
            num_2 = 1;
            num_3 = 1;
            for i=1:tm.d;
               if d>0;
                  ch_d1 = sum(i==dum_1);
               else;
                  ch_d1 = 0;
               end;
               if isempty(dum_2)==0;
                  ch_d2 = sum(i==dum_2);
               else;
                  ch_d2 = 0;
               end;
               ch_d3 = sum(i==dum_3);
               if ch_d1==1;
                  low = 1+tm.n*(num_1-1);
                  up = tm.n*num_1;
                  m_help = h1_mat(low:up,:);
                  num_1 = num_1+1;
               elseif ch_d2==1;
                  low = 1+tm.n*(num_2-1);
                  up = tm.n*num_2;
                  m_help = h2_mat(low:up,:);
                  num_2 = num_2+1;
               else;
                  low = 1+tm.n*(num_3-1);
                  up = tm.n*num_3;
                  m_help = h3_mat(low:up,:);
                  num_3 = num_3+1;
               end;
               Help_mat = [Help_mat;m_help];
            end;
            H_mat = [Help_mat;H_mat];
            dm.Sigma_theta = H_mat*info_mat*H_mat';
         end;
      end;
      %
      % make sure that any restrictions files we have created are deleted
      %
      if (tm.restrict(1,2)==1)&(isempty(lr_dummies)==0);
         file_norm_new = strcat(tm.modelsdir,'normalize-',num2str(tm.n),'x',num2str(tm.r),'x',num2str(tm.dcoint+tm.q1+size(lr_dummies,2)),'-',tm.modelfile,'.norm');
         delete_file_fcn(file_norm_new);
         file_norm_cp = [file_norm_new '.bak'];
         if fileexist(file_norm_cp)==1;
            rename_file_fcn(file_norm_cp,file_norm_new);
         end;
         for i=1:tm.r;
            file_new = strcat(tm.modelsdir,'H_',num2str(i),'-',num2str(tm.n),'x',num2str(tm.r),'x',num2str(tm.dcoint+tm.q1+size(lr_dummies,2)),'-',tm.modelfile,'.rest');
            delete_file_fcn(file_new);
            file_cp = [file_new '.bak'];
            if fileexist(file_cp)==1;
               rename_file_fcn(file_cp,file_new);
            end;
         end;
      end;
      %
      % display the results
      %
      if strcmp(abort,'cancel')==0;
         txt = strvcat(' ',['TESTING RESTRICTIONS FOR DETERMINISTIC VARIABLES (for rank=' num2str(tm.r) ')']);
         numchar = size(txt,2);
         addtxt = '';
         for i=1:numchar;
            addtxt = strcat(addtxt,'=');
         end;
         txt = strvcat(txt,addtxt,' ');
         txt = strvcat(txt,'  LR-type test statistic','  ~~~~~~~~~~~~~~~~~~~~~~',' ');
         %
         if isempty(prop_dummies)==0;
            pd_str = strtrim(prop_dummy_names(1,:));
            for i=2:size(prop_dummy_names,1);
               pd_str = [pd_str ', ' strtrim(prop_dummy_names(i,:))];
            end;
            pd_null = ' have proportional parameters';
            pd_alt = ' do not have proportional parameters';
         else;
            pd_str = '';
            pd_null = '';
            pd_alt = '';
         end;
         %
         if isempty(lr_dummies)==0;
            lr_str = strtrim(lr_dummy_names(1,:));
            for i=2:size(lr_dummy_names,1);
               lr_str = [lr_str ', ' strtrim(lr_dummy_names(i,:))];
            end;
            lr_null = ' have zero long run effect on all endogenous variables';
            lr_alt = ' do not have zero long run effect on all endogenous variables';
         else;
            lr_str = '';
            lr_null = '';
            lr_alt = '';
         end;
         %
         and_str = '';
         or_str = '';
         if (strcmp(pd_str,'')==0)&(strcmp(lr_str,'')==0);
            and_str = ' and ';
            or_str = ' or ';
         end;
         null_str = strvcat([pd_str pd_null and_str],[lr_str lr_null]);
         null_intro = strvcat('Null Hypothesis:        ',' ');
         null_str = [null_intro(1:size(null_str,1),:) null_str];
         alt_str = strvcat([pd_str pd_alt or_str],[lr_str lr_alt]);
         alt_intro = strvcat('Alternative Hypothesis: ',' ');
         alt_str = [alt_intro(1:size(alt_str,1),:) alt_str];
         txt = strvcat(txt,null_str,alt_str,' ');
         %
         % display the test
         %
         if curr_ini.sscorrect==0;
            if test>0;
               txt = strvcat(txt,['LR(' num2str(deg_free,'%0.0f') ')  = ' num2str(test,['%0.' num2str(curr_ini.decimals,'%0.0f') 'f'])]);
               txt = strvcat(txt,['p-value = ' num2str(pval,['%0.' num2str(curr_ini.decimals,'%0.0f') 'f'])],' ');
            else;
               txt = strvcat(txt,['LR(' num2str(deg_free,'%0.0f') ') yields bad value - Possible convergence problem under the alternative'],' ');
            end;
         else;
            if test>0;
               txt = strvcat(txt,['F(' num2str(deg_free(1,1),'%0.0f') ',' num2str(deg_free(1,2),'%0.0f') ') = ' num2str(test,['%0.' num2str(curr_ini.decimals,'%0.0f') 'f'])]);
               txt = strvcat(txt,['p-value  = ' num2str(pval,['%0.' num2str(curr_ini.decimals,'%0.0f') 'f'])],' ');
            else;
               txt = strvcat(txt,['F(' num2str(deg_free(1,1),'%0.0f') ',' num2str(deg_free(1,2),'%0.0f') ') yields bad value - Possible convergence problem under the alternative']);
            end;
         end;
         %
         delta = dm.Psi(:,1:tm.d);
         delta_std = sqrt(abs(diag(dm.Sigma_theta(1:tm.n*tm.d,1:tm.n*tm.d))));
         delta_std = vecinv(delta_std,tm.n);
         delta_t = inf2nan(delta./delta_std);
         %
         p_est = '%s';
         p_std = spacestr(size(tm.myvars,2));
         p_t = p_std;
         deter_vec = vecstr(tm.deter);
         d_str = p_std;
         d_size = size(deter_vec,2);
         if d_size<=6+curr_ini.decimals;
            add_sp = '';
            add_deter_str = spacestr(8+curr_ini.decimals-d_size);
         else;
            add_sp = spacestr(d_size-(6+curr_ini.decimals));
            add_deter_str = '  ';
         end;
         for i=1:tm.d;
            d_str = [d_str add_deter_str deter_vec(i,:) ' '];
            p_est = [p_est add_sp '  %' num2str(6+curr_ini.decimals,'%0.0f') '.' num2str(curr_ini.decimals,'%0.0f') 'f '];
            p_std = [p_std ' (%' num2str(6+curr_ini.decimals,'%0.0f') '.' num2str(curr_ini.decimals,'%0.0f') 'f)'];
            p_t = [p_t add_sp ' [%' num2str(6+curr_ini.decimals,'%0.0f') '.' num2str(curr_ini.decimals,'%0.0f') 'f]'];
         end;
         %
         txt = strvcat(txt,' ','Estimated parameters on the deterministics with asymptotic standard errors and t-ratios:',' ',d_str);
         for i=1:tm.n;
            txt = strvcat(txt,sprintf(p_est,tm.myvars(i,:),delta(i,:)'));
            txt = strvcat(txt,sprintf(p_std,delta_std(i,:)'));
            txt = strvcat(txt,sprintf(p_t,delta_t(i,:)'));
         end;
         txt = strvcat(txt,' ');
         %
         % align the text as well as possible
         %
         txt = swapallchars(txt,'(');
         txt = swapallchars(txt,'[');
         %
         add_width = 0;
         add_height = 0;
         if isempty(lr_dummies)==0;
            add_width = 50;
            if tm.realscrsz(3)>800;
               add_width = 130;
               add_height = 50;
            end;
         end;
         %
         textgui(txt,'Proportionality Restrictions',[(tm.realscrsz(3)-750-add_width)/2 (tm.realscrsz(4)-500-add_height)/2 750+add_width 500+add_height],'Results',38);
         set(pdd_graph.apply,'Enable','on','UserData',dm);
         if isfield(tm,'dm')==1;
            tm = rmfield(tm,'dm');
         end;
      end;
      set(pdd,'Visible','on');
      drawnow;
   case 'radio_button'
      pos = get(gco,'UserData');
      tag = get(gco,'Tag');
      if strcmp(tag,'longrun')==1;
         set(pdd_graph.prop_controls(1,pos),'Value',0);
      else;
         set(pdd_graph.longrun_controls(1,pos),'Value',0);
      end;
      if strcmp(get(pdd_graph.longrun_controls(1,pos),'Enable'),'off')==1;
         set(pdd_graph.prop_controls(1,pos),'Value',1);
      else;
         set(pdd_graph.save,'Enable','on');
         file = [tm.modelsdir 'dummy-ir-selection-' tm.modelfile '-' num2str(tm.n,'%0.0f') '.' num2str(tm.r,'%0.0f') '-' num2str(tm.num_dummies,'%0.0f') '.' num2str(tm.num_const,'%0.0f') '.mat'];
         if fileexist(file)==1;
            set(pdd_graph.restore,'Enable','on');
         end;
      end;
   case 'check_boxes'
      pos = get(gco,'UserData');
      val = get(gco,'Value');
      if val==1;
         if (tm.r<tm.n)&(tm.r>0);
            set(pdd_graph.longrun_controls(1,pos),'Enable','on','Value',1);
            if tm.datad>1;
               set(pdd_graph.prop_controls(1,pos),'Enable','on','Value',0);
            end;
         else;
            if tm.datad>1;
               set(pdd_graph.prop_controls(1,pos),'Enable','on','Value',1);
            end;
         end;
      else;
         set(pdd_graph.longrun_controls(1,pos),'Enable','off','Value',0);
         set(pdd_graph.prop_controls(1,pos),'Enable','off','Value',0);
      end;
      %
      % check if we have restrictions that allow use to estimate
      %
      rest = 0;
      for i=1:size(pdd_graph.rest_controls,2);
         rest = rest+get(pdd_graph.rest_controls(1,i),'Value');
      end;
      if rest>0;
         set(pdd_graph.save,'Enable','on');
         set(pdd_graph.estimate,'Enable','on');
      else;
         set(pdd_graph.save,'Enable','off');
         set(pdd_graph.estimate,'Enable','off');
         set(pdd_graph.apply,'Enable','off','UserData',[]);
      end;
      file = [tm.modelsdir 'dummy-ir-selection-' tm.modelfile '-' num2str(tm.n,'%0.0f') '.' num2str(tm.r,'%0.0f') '-' num2str(tm.num_dummies,'%0.0f') '.' num2str(tm.num_const,'%0.0f') '.mat'];
      if fileexist(file)==1;
         set(pdd_graph.restore,'Enable','on');
      end;
   case 'save'
      %
      % collect the data
      %
      dummies = zeros(size(pdd_graph.rest_controls,2),3);
      for i=1:size(pdd_graph.rest_controls,2);
         dummies(i,1) = get(pdd_graph.rest_controls(1,i),'Value');
         dummies(i,2) = get(pdd_graph.longrun_controls(1,i),'Value');
         dummies(i,3) = get(pdd_graph.prop_controls(1,i),'Value');
      end;
      file = [tm.modelsdir 'dummy-ir-selection-' tm.modelfile '-' num2str(tm.n,'%0.0f') '.' num2str(tm.r,'%0.0f') '-' num2str(tm.num_dummies,'%0.0f') '.' num2str(tm.num_const,'%0.0f') '.mat'];
      save(file,'dummies');
      set(pdd_graph.save,'Enable','off');
      set(pdd_graph.restore,'Enable','off');
   case 'restore'
      file = [tm.modelsdir 'dummy-ir-selection-' tm.modelfile '-' num2str(tm.n,'%0.0f') '.' num2str(tm.r,'%0.0f') '-' num2str(tm.num_dummies,'%0.0f') '.' num2str(tm.num_const,'%0.0f') '.mat'];
      if fileexist(file)==1;
         a = load(file);
         if (isfield(a,'dummies')==1)&(size(a.dummies,1)==size(pdd_graph.var_controls,2));
            for i=1:size(pdd_graph.rest_controls,2);
               set(pdd_graph.rest_controls(1,i),'Value',a.dummies(i,1));
               en_str = 'off';
               if a.dummies(i,1)==1;
                  en_str = 'on';
               end;
               if (tm.r<tm.n)&(tm.r>0);
                  set(pdd_graph.longrun_controls(1,i),'Value',a.dummies(i,2),'Enable',en_str);
               end;
               set(pdd_graph.prop_controls(1,i),'Value',a.dummies(i,3),'Enable',en_str);
               if sum(sum(a.dummies))>0;
                  set(pdd_graph.estimate,'Enable','on');
               end;
            end;
         end;
      end;
      set(pdd_graph.save,'Enable','off');
      set(pdd_graph.restore,'Enable','off');
   case 'apply'
      dm = get(pdd_graph.apply,'UserData');
      tm.dm = dm;
      set(pdd_graph.estimate,'UserData',tm);
      set(pdd_graph.apply,'Enable','off','UserData','applied');
   case 'done'
      tm.action = lower(get(gco,'Tag'));
      if (isempty(tm.action)==1)|(strcmp(tm.action,'cancel')==0);
         tm.action = 'done';
      end;
      set(pdd_graph.estimate,'UserData',tm);
      set(pdd_graph.done,'UserData','done');
end;

if strcmp(selector,'init')==1;
   if (iswinnt==1)&(iscompiled==1)&(curr_ini.loadguiicon==1);
      prog = ['bin\runwindow.exe ' fix_path([pwd '\bin\seticon.exe']) ' ' get(pdd,'Name') ' ' fix_filepath([pwd '\icons\deterprop.ico'])];
      dos(prog);
      if (strcmp(curr_ini.pstoolsdir,'')==0)&(appexist([curr_ini.pstoolsdir 'pslist.exe'])==1);
         %
         % now we need to determine the pid
         %
         pid = getpid('seticon');
         set(pdd_graph.icon,'UserData',pid);
      end;
   end;
   %
   set(pdd,'Visible','on');
   drawnow;
   drawnow;
   if (iswinnt==1)&(iscompiled==1)&(matlabnumber<7);
      drawnow;
      prog = ['bin\run_prog.exe ' fix_path([pwd '\bin\setfocus.exe']) ' ' get(pdd,'Name') ' 3'];
      dos(prog);
      drawnow;
   elseif matlabnumber>=7;
      uicontrol(pdd_graph.done);
   end;
   waitfor(pdd_graph.done,'UserData','done');
   if nargout==1;
      cm = get(pdd_graph.estimate,'UserData');
      cm.applied = get(pdd_graph.apply,'UserData');
   end;
   killguipid(pdd);
end;

%
% end of restrict_dummies_dlg.m
%
