%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                %
%          MatLab functions for creating seasonal dummies        %
%                                                                %
%          Function: seasonal_fcn                                %
%                                                                %
%          Input:                                                %
%                       freq: text string                        %
%          	            T: sample size (integer)                 %
%                                                                %
%          Output:                                               %
%          	            seamat: matrix with centered seasonal    %
%                           dummies                              %
%                       seastring: text string                   %
%                                                                %
%          This version:        June 1, 2004                     %
%          Written by: 	        Anders Warne                     %
%                               Copyright (c) 2001-2004          %
%                                                                %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [seamat,seastring] = seasonal_fcn(freq,T)

seamat = [];
if strcmp(freq,'q');
   seamat_base = [[eye(3)-0.25];[-ones(1,3)*0.25]];
   seastring = 's1 s2 s3';
   num = floor(T/4);
   extra = T-num*4;
elseif strcmp(freq,'m');
   seamat_base = [[eye(11)-1/12];[-ones(1,11)*(1/12)]];
   seastring = 's1 s2 s3 s4 s5 s6 s7 s8 s9 s10 s11';
   num = floor(T/12);
   extra = T-num*12;
end;

for i=1:num;
   seamat = [seamat;seamat_base];
end;

if extra>0;
   seamat = [seamat;seamat_base(1:extra,:)];
end;

%
% end of seasonal_fcn.m
%