function [status,num_res,tot_res,B_random,keep_rest,del_rest,use_psi_rest,C_rank] = test_ident_m2(tm,type_var)

%
% status = 0 means valid identification, 1 means
% too few restrictions, 2 means that B is singular,
% 3 means that some restrictions are redundant, 4
% means that some long-run restrictions can't be met,
% 5 that the rank of C is affected by the restrictions.
% status = 7 means aborting check
%

B_random = [];
status = 1;
C_rank = [];
use_psi_rest = [];
keep_rest = [];
del_rest = [];

curr_ini = find_inisettings;

if strcmp(type_var,'short_run')==1;
   file = strcat(tm.modelsdir,'F-',int2str(tm.n),'x',int2str(tm.r),'-',tm.modelfile,'.rest');
   F = loaddata(file);
   num_res = size(F,1);
   tot_res = num_res;
   keep_rest = (1:1:tot_res)';
   del_rest = [];
   [Rmat_sr,rvec_sr] = rmatrix(F,tm.n,tm.n);
   if rank(Rmat_sr)==size(F,1);
      if size(Rmat_sr,1)<(tm.n*(tm.n-1))/2;
         return;
      end;
   else;
      return;
   end;
   Rmat = Rmat_sr;
   rvec = rvec_sr;
%   S = null(Rmat,'r');
   S = null(Rmat);
   d = (Rmat'/(Rmat*Rmat'))*rvec;
   vB = (S*randn(size(S,2),1))+d;
   B = vecinv(vB,tm.n);
   B_random = B;
   if rank(B)==tm.n;
      %
      % Need to check for identification using Rothenberg (1971, Theorem 2)
      %
      B_inv = B\eye(tm.n);
      Nn = ncommutation(tm.n);
      i_b = kron(eye(tm.n),B_inv);
      info_mat = 2*i_b'*Nn*i_b;
      test_mat = [info_mat;Rmat];
      if rank(test_mat)==floor(tm.n*tm.n);
         status = 0;
      end;
   else;
      status = 2;
   end;
   i_state = 0;
   keep_rest.entry(1,1).rest = keep_rest;
   del_rest.entry(1,1).rest = [];
   use_psi_rest.entry(1,1).rest = [];
elseif strcmp(type_var,'long_run')==1;
   file = strcat(tm.modelsdir,'LF-',int2str(tm.n),'x',int2str(tm.r),'-',tm.modelfile,'.rest');
   LF = loaddata(file);
   num_res = size(LF,1);
   tot_res = num_res;
   keep_rest_global = (1:1:tot_res)';
   del_rest_global = [];
   if (tm.r>0)&(tm.r<tm.n)&(tm.r-1>0);
      return;
   end;
   [Rmat_lr,rvec_lr] = rmatrix(LF,tm.n,tm.n);
   if tm.r<=1;
      C = cmat(tm.Psi,tm.alpha,tm.beta,tm.epsilon,tm.Z1,tm.Z2,tm.p,tm.d,0);
   else;
      C = cmat_stat(tm.Psi,tm.alpha,tm.beta,tm.epsilon,tm.Z1,tm.Z2,tm.p,tm.d,0,[]);
   end;
   if (tm.r==0)|(tm.r==tm.n);
      beta_orth = eye(tm.n);
      Gamma_mat = C;
   else;
      beta_orth = null(tm.beta(1:tm.n,:)');
      Gamma_mat = (beta_orth'*beta_orth)\(beta_orth'*C);
   end;
   C_rank = rank(C);
   old_Rmat_lr = Rmat_lr;
   Rmat_lr = Rmat_lr*kron(eye(tm.n),C);
   %
   % check if restricted C makes any long-run restrictions redundant
   %
   if tm.restrict(1,3)==1;
      check_lr_rest = old_Rmat_lr*vec(C*randn(tm.n,tm.n))-rvec_lr;
      if curr_ini.convcrit<10;
         ch_convcrit = ['1.0e-00' num2str(curr_ini.convcrit)];
      else;
         ch_convcrit = ['1.0e-0' num2str(curr_ini.convcrit)];
      end;
      ccrit = mystr2num(ch_convcrit);
      k_rest = [];
      for i=1:size(check_lr_rest,1);
         if abs(check_lr_rest(i,1))>ccrit;
            k_rest = [k_rest;i];
         end;
      end;
      if isempty(k_rest)==0;
         old_Rmat_lr = old_Rmat_lr(k_rest,:);
         Rmat_lr = Rmat_lr(k_rest,:);
         rvec_lr = rvec_lr(k_rest,1);
         num_res = rank(Rmat_lr);
      else;
         old_Rmat_lr = [];
         Rmat_lr = [];
         rvec_lr = [];
         num_res = 0;
      end;
   end;
   %
   if rank(Rmat_lr)==size(LF,1);
      if size(Rmat_lr,1)<(tm.n*(tm.n-1))/2;
         return;
      end;
   else;
      return;
   end;
   Rmat = Rmat_lr;
   rvec = rvec_lr;
   Rmat_sr = [];
   rvec_sr = [];
   %
   Nn = ncommutation(tm.n);
   if tm.restrict(1,1)==1;
      file = strcat(tm.modelsdir,'G-',int2str(tm.n),'x',int2str(tm.r),'-',tm.modelfile,'.rest');
      G = loaddata(file);
      [Rmat_alpha,rvec_alpha] = rmatrix(G,tm.n,tm.r);
      if isempty(tm.Z2)==0;
         Rmat_alpha = [zeros(size(G,1),size(tm.Z2,1)*tm.n) Rmat_alpha];
      end;
      xi = xi_mat(C,tm.Psi,tm.alpha,tm.p,tm.pe,tm.r,tm.d,tm.q1,tm.q0);
   else;
      Rmat_alpha = [];
   end;
   %
   % Check if we have restrictions on C
   %
   if (size(tm.restrict,2)==3)&(tm.restrict(1,3)==1);
      file = strcat(tm.modelsdir,'C-',int2str(tm.n),'x',int2str(tm.r),'-',tm.modelfile,'.rest');
      Cres = loaddata(file);
      [Rmat_C,rvec_C] = rmatrix(Cres,tm.n,tm.n);
      xi = xi_mat(C,tm.Psi,tm.alpha,tm.p,tm.pe,tm.r,tm.d,tm.q1,tm.q0);
      g_c = Rmat_C*kron(xi',C);
      if rank(g_c)<size(g_c,1);
         [red_rest,use_rest] = getdelvars(g_c',[]);
         Rmat_C = Rmat_C(use_rest,:);
         rvec_C = rvec_C(use_rest,1);
      end;
   else;
      Rmat_C = [];
      rvec_C = [];
   end;
   n_states = size(Rmat_lr,1);
   %
   % check if we have already saved the necessary data to do estimation
   %
   file = strcat(tm.modelsdir,'structural-rest-',type_var,'-',int2str(tm.n),'x',int2str(tm.r),'x',int2str(tot_res),'x',int2str(n_states),'-',num2str(tm.restrict(1,2)),'x',num2str(tm.restrict(1,1)),'x',num2str(size(Rmat_alpha,1)),'-',num2str(tm.restrict(1,3)),'x',num2str(size(Rmat_C,1)),'-',tm.modelfile,'.mat');
   if fileexist(file)==1;
      my_rest = load(file);
      if (isfield(my_rest,'keep_rest')==1)&(isfield(my_rest,'del_rest')==1)&(isfield(my_rest,'use_psi_rest')==1);
         %
         % need to check the date of 3 files
         %
         % 1. stored_date for the mat-file
         % 2. lr_date for the LR restrictions file
         %
         stored_date = getfiledate(file);
         %
         file = strcat(tm.modelsdir,'LF-',int2str(tm.n),'x',int2str(tm.r),'-',tm.modelfile,'.rest');
         lr_date = getfiledate(file);
         %
         % we should also check all relevant restrictions on beta and on alpha
         %
         if tm.restrict(1,2)==1;
            beta_test = 1;
            alpha_test = 1;
            for i=1:tm.r;
               file = strcat(tm.modelsdir,'H_',num2str(i),'-',num2str(tm.n),'x',num2str(tm.r),'x',num2str(tm.dcoint+tm.q1),'-',tm.modelfile,'.rest');
               beta_date = getfiledate(file);
               if beta_date>stored_date;
                  beta_test = 0;
                  break;
               end;
            end;
            %
            % now we do the alpha file
            %
            if (beta_test==1)&(tm.restrict(1,1)==1);
               file = strcat(tm.modelsdir,'G-',int2str(tm.n),'x',int2str(tm.r),'-',tm.modelfile,'.rest');
               alpha_date = getfiledate(file);
               if alpha_date>stored_date;
                  alpha_test = 0;
               end;
            end;
         else;
            beta_test = 1;
            alpha_test = 1;
         end;
         %
         % now we do the C file
         %
         if tm.restrict(1,3)==1;
            c_test = 1;
            file = strcat(tm.modelsdir,'C-',int2str(tm.n),'x',int2str(tm.r),'-',tm.modelfile,'.rest');
            c_date = getfiledate(file);
            if c_date>stored_date;
               c_test = 0;
            end;
         else;
            c_test = 1;
         end;
         %
         % now we check if stored_date is more recent than the other 2
         %
         if (stored_date>lr_date)&(beta_test==1)&(alpha_test==1)&(c_test==1);
            %
            % we've done this before. no need to recompute!
            %
            status = 0;
            keep_rest = my_rest.keep_rest;
            del_rest = my_rest.del_rest;
            use_psi_rest = my_rest.use_psi_rest;
            %
            % before we leave we should return a B_random matrix
            %
            new_Rmat = Rmat(keep_rest.entry(1,1).rest,:);
            new_rvec = rvec(keep_rest.entry(1,1).rest,1);
            S = null(new_Rmat);
            H_Rmat = null(S');
            d = (H_Rmat/(new_Rmat*H_Rmat))*new_rvec;
            vB = (S*randn(size(S,2),1))+d;
            B_random = vecinv(vB,tm.n);
            return;
         end;
      end;
   end;
   %
   % construct the necessary data for estimation or signal bad restrictions
   %
   oid_rest = (size(Rmat_lr,1)+size(Rmat_sr,1)-((tm.n*(tm.n-1))/2));
   if oid_rest==0;
      states = zeros(1,n_states);
   else;
      if strcmp(computer,'PCWIN')==1;
         file = [pwd '\mat\states-' num2str(n_states,'%0.0f') '.' num2str(oid_rest,'%0.0f') '.mat'];
      else;
         file = [pwd '/mat/states-' num2str(n_states,'%0.0f') '.' num2str(oid_rest,'%0.0f') '.mat'];
      end;
      if fileexist(file)==1;
         states_data = load(file);
         states = states_data.states;
         clear('states_data');
      else;
         %
         % ask if we should proceed
         %
         txt = ['Structural VAR needs to calculate all combinations of ' num2str(n_states,'%0.0f') ' states. This may take some time, but is only needed once. Are you sure you want to continue?'];
         answer = query(txt,'question',120,'Structural VAR - Combinations',500,'no');
         if strcmp(answer,'Yes')==1;
            %
            % show a wait dialog
            %
            txt = strvcat(' ',['Determining the number of combinations of ' num2str(n_states,'%0.0f') ' states to test for local identification...'],'Please hold!');
            mywait = waitdlg(txt,'information');
            waitf = get(mywait,'UserData');
            states = var_comb(n_states);
            txt = strvcat(' ','Saving data to file...','Please hold!');
            set(waitf.text,'String',txt);
            %
            % save to disk
            %
            if strcmp(computer,'PCWIN')==1;
               file = [pwd '\mat\states-' num2str(n_states,'%0.0f') '.' num2str(n_states,'%0.0f') '.mat'];
            else;
               file = [pwd '/mat/states-' num2str(n_states,'%0.0f') '.' num2str(n_states,'%0.0f') '.mat'];
            end;
            %
            save(file,'states');
            %
            f_states = states;
            clear('states');
            %
            if n_states>1;
               for j=1:n_states-1;
                  if j<n_states-1;
                     states = [];
                     for k=1:size(f_states,1);
                        stat_r = f_states(k,:);
                        stat_r = stat_r(stat_r~=0);
                        if size(stat_r,2)<=j;
                           states = [states;f_states(k,:)];
                        end;
                     end;
                  else;
                     states = f_states(1:size(f_states,1)-1,:);
                  end;
                  if strcmp(computer,'PCWIN')==1;
                     file = [pwd '\mat\states-' num2str(n_states,'%0.0f') '.' num2str(j,'%0.0f') '.mat'];
                  else;
                     file = [pwd '/mat/states-' num2str(n_states,'%0.0f') '.' num2str(j,'%0.0f') '.mat'];
                  end;
                  save(file,'states');
               end;
               clear('states');
            end;
            clear('f_states');
            %
            % now load the correct file with states
            %
            if strcmp(computer,'PCWIN')==1;
               file = [pwd '\mat\states-' num2str(n_states,'%0.0f') '.' num2str(oid_rest,'%0.0f') '.mat'];
            else;
               file = [pwd '/mat/states-' num2str(n_states,'%0.0f') '.' num2str(oid_rest,'%0.0f') '.mat'];
            end;
            states_data = load(file);
            states = states_data.states;
            clear('states_data');
            %
            % close wait dialog
            %
            set(waitf.text,'UserData','done');
            delete(mywait);
         else;
            status = 6;
         end;
      end;
   end;
   %
   % initialize the different case checks
   %
   if status==6;
      return;
   end;
   abort = '';
   success_num = 0;
   i_state = 0;
   while (i_state<=size(states,1)-1)&(strcmp(abort,'cancel')==0);
      i_state = i_state+1;
      %
      % open the progress dialog
      %
      if i_state==1;
         %
         % set up a progress bar
         %
         num_trials = size(states,1);
         input_var.title = ['Progress for maximum of ' int2str(num_trials) ' trials'];
         input_var.facecolor = curr_ini.progress_facecolor;
         input_var.startfacecolor = curr_ini.progress_startfacecolor;
         input_var.edgecolor = curr_ini.progress_edgecolor;
         input_var.bgcolor = curr_ini.progress_bgcolor;
         input_var.label = 'Trial number:';
         input_var.stop = 0;
         input_var.clock = 1;
         input_var.name = 'Checking Long-Run Restrictions';
         mywait = progressdlg(0,input_var);
%         set(mywait,'Name','Checking Long-Run Restrictions');
         set(mywait,'Color',get(0,'defaultuicontrolbackgroundcolor'));
         drawnow;
      elseif i_state>1;
         %
         % update the progress bar
         %
         abort = get(mywait,'UserData');
         if strcmp(abort,'cancel')==0;
            progressdlg([(i_state/num_trials) i_state]);
         end;
      end;
      %
      % create new del_rest_local and keep_rest_local variables
      %
      r_num = states(i_state,:);
      r_num = r_num(r_num~=0);
      %
      if isempty(r_num)==0;
         r_num = (r_num');
      end;
      del_rest_local = unique([del_rest_global;r_num]);
      keep_rest_local = setdiff(keep_rest_global,del_rest_local);
      %
      % create new restrictions matrices and check their rank
      %
      new_Rmat = Rmat(keep_rest_local,:);
      new_rvec = rvec(keep_rest_local,1);
      %
      % we only need to evaluate those cases where new_Rmat has
      % full row rank
      %
      if rank(new_Rmat)==size(new_Rmat,1);
         %
         % Now we create a random B matrix and check its rank
         %
         S = null(new_Rmat);
         d = (new_Rmat'/(new_Rmat*new_Rmat'))*new_rvec;
         vB = (S*randn(size(S,2),1))+d;
         B_rand = vecinv(vB,tm.n);
         if rank(B_rand)==tm.n;
            %
            % with B_rand having the correct rank we next need to check a random
            % C satisfying all the long-run restrictions
            %
            %
            % create the linear restrictions on C
            %
            c_Rmat = old_Rmat_lr*kron(B_rand',beta_orth);
            c_rvec = rvec_lr;
            if (size(tm.restrict,2)==3)&(tm.restrict(1,3)==1);
               c_Rmat = [Rmat_C*kron(eye(tm.n),beta_orth);c_Rmat];
               c_rvec = [rvec_C;c_rvec];
               if rank(c_Rmat)<size(c_Rmat,1);
                  [red_rest_h,use_rest_h] = getdelvars(c_Rmat',[]);
                  c_Rmat = c_Rmat(use_rest_h,:);
                  c_rvec = c_rvec(use_rest_h,1);
               end;
            end;
            %
            % create a C which can satisfies the del_rest_local restrictions and which
            % should be able to have the correct rank
            %
            S_c = null(c_Rmat);
            H_c = null(S_c');
            d_c = (H_c/(c_Rmat*H_c))*c_rvec;
            psi_c = (S_c'*S_c)\(S_c'*(vec(Gamma_mat)-d_c));
            vC = (S_c*psi_c)+d_c;
            if (tm.r==0)|(tm.r==tm.n);
               C_new = vecinv(vC,tm.n);
            else;
               C_new = beta_orth*vecinv(vC,tm.n-tm.r);
            end;
            %
            % now check if B_rand and C_new satisfy all long-run restrictions
            %
            rest_values = (old_Rmat_lr*vec(C_new*B_rand))-rvec_lr;
            %
            % now add the C restrictions to rest_values if applicable
            %
            if (size(tm.restrict,2)==3)&(tm.restrict(1,3)==1);
               rest_values = [rest_values;Rmat_C*vec(C_new)-rvec_C];
            end;
            %
            if (max(abs(rest_values))<1.0e-008)&(rank(C_new)==rank(C));
               %
               % At this stage both B_rand and C_new are valid, i.e. B_rand
               % has full rank, C_new has the same rank as C, and C_mew*B_rand
               % satisfy all long-run restrictions
               %
               %
               % we need to check how the long-run restrictions interact with restrictions
               % on alpha
               %
               if tm.restrict(1,1)==1;
                  if (size(tm.restrict,2)==3)&(tm.restrict(1,3)==1);
                     c_Rmat = [Rmat_alpha;Rmat_C*kron(eye(tm.n),C);old_Rmat_lr*kron(B_rand'*xi',C)];
                  else;
                     c_Rmat = [Rmat_alpha;old_Rmat_lr*kron(B_rand'*xi',C)];
                  end;
                  if rank(c_Rmat)<size(c_Rmat,1);
                     [red_rest_local,use_psi_rest_local] = getdelvars(c_Rmat',[]);
                     red_rest_local = red_rest_local-rank([Rmat_alpha;Rmat_C*kron(xi',C)]);
                  else;
                     use_psi_rest_local = (1:1:size(c_Rmat,1))';
                  end;
               else;
                  if (size(tm.restrict,2)==3)&(tm.restrict(1,3)==1);
                     c_Rmat = [Rmat_C*kron(xi',C);old_Rmat_lr*kron(B_rand'*xi',C)];
                     if rank(c_Rmat)<size(c_Rmat,1);
                        [red_rest_local,use_psi_rest_local] = getdelvars(c_Rmat',[]);
                        red_rest_local = red_rest_local-size(Rmat_C,1);
                     else;
                        use_psi_rest_local = (1:1:size(c_Rmat,1))';
                     end;
                  else;
                     use_psi_rest_local = (1:1:size(old_Rmat_lr,1))';
                  end;
               end;
               %
               % we should select an Rmat version which uses C_new
               % creating a new B_rand and check its rank
               %
               B_Rmat = old_Rmat_lr*kron(eye(tm.n),C_new);
               B_Rmat = B_Rmat(keep_rest_local,:);
               if rank(B_Rmat)==size(B_Rmat,1);
                  B_rvec = rvec(keep_rest_local,1);
                  S = null(B_Rmat);
                  H_Rmat = null(S');
                  d = (H_Rmat/(B_Rmat*H_Rmat))*B_rvec;
                  vB = (S*randn(size(S,2),1))+d;
                  B_rand = vecinv(vB,tm.n);
                  %
                  if rank(B_rand)==tm.n;
                     %
                     % Need to check for local identification of B_rand using Rothenberg (1971, Theorem 2)
                     % and that S'*info_mat*S is invertible
                     %
                     B_inv = B_rand\eye(tm.n);
                     i_b = kron(eye(tm.n),B_inv);
                     info_mat = 2*i_b'*Nn*i_b;
                     g_info = S'*info_mat*S;
                     if rank(g_info)==size(g_info,1);
                        test_mat = [info_mat;B_Rmat];
                        if rank(test_mat,eps)==floor(tm.n*tm.n);
                           success_num = success_num+1;
                           keep_rest.entry(success_num,1).rest = keep_rest_local;
                           del_rest.entry(success_num,1).rest = del_rest_local;
                           use_psi_rest.entry(success_num,1).rest = use_psi_rest_local;
                           status = 0;
                           B_random = B_rand;
                        end;
                     end;
                  end;
               end;
            end;
         end;
      end;
   end;
   %
   % close down the progress dialog
   %
   set(mywait,'UserData','done');
   close(mywait);
   drawnow;
   clear('states');
   %
   if strcmp(abort,'cancel')==1;
      status = 7;
   else;
      %
      % save data to file if we have any data to save
      %
      if status==0;
         file = strcat(tm.modelsdir,'structural-rest-',type_var,'-',int2str(tm.n),'x',int2str(tm.r),'x',int2str(tot_res),'x',int2str(n_states),'-',num2str(tm.restrict(1,2)),'x',num2str(tm.restrict(1,1)),'x',num2str(size(Rmat_alpha,1)),'-',num2str(tm.restrict(1,3)),'x',num2str(size(Rmat_C,1)),'-',tm.modelfile,'.mat');
         save(file,'keep_rest','del_rest','use_psi_rest');
      end;
   end;
else;
   %
   % this case allows for tm.r>0 and tm.r<tm.n
   %
   file = strcat(tm.modelsdir,'F-',int2str(tm.n),'x',int2str(tm.r),'-',tm.modelfile,'.rest');
   F = loaddata(file);
   [Rmat_sr,rvec_sr] = rmatrix(F,tm.n,tm.n);
   %
   file = strcat(tm.modelsdir,'LF-',int2str(tm.n),'x',int2str(tm.r),'-',tm.modelfile,'.rest');
   LF = loaddata(file);
   [Rmat_lr,rvec_lr] = rmatrix(LF,tm.n,tm.n);
   %
   if tm.r<tm.n;
      C = cmat(tm.Psi,tm.alpha,tm.beta,tm.epsilon,tm.Z1,tm.Z2,tm.p,tm.d,0);
   else;
      C = cmat_stat(tm.Psi,tm.alpha,tm.beta,tm.epsilon,tm.Z1,tm.Z2,tm.p,tm.d,0,[]);
   end;
   if (tm.r==0)|(tm.r==tm.n);
      beta_orth = eye(tm.n);
      Gamma_mat = C;
   else;
      beta_orth = null(tm.beta(1:tm.n,:)');
      Gamma_mat = (beta_orth'*beta_orth)\(beta_orth'*C);
   end;
   C_rank = rank(C);
   old_Rmat_lr = Rmat_lr;
   Rmat_lr = Rmat_lr*kron(eye(tm.n),C);
   %
   % check if restricted C makes any long-run restrictions redundant
   %
   if tm.restrict(1,3)==1;
      check_lr_rest = old_Rmat_lr*vec(C*randn(tm.n,tm.n))-rvec_lr;
      if curr_ini.convcrit<10;
         ch_convcrit = ['1.0e-00' num2str(curr_ini.convcrit)];
      else;
         ch_convcrit = ['1.0e-0' num2str(curr_ini.convcrit)];
      end;
      ccrit = mystr2num(ch_convcrit);
      k_rest = [];
      for i=1:size(check_lr_rest,1);
         if abs(check_lr_rest(i,1))>ccrit;
            k_rest = [k_rest;i];
         end;
      end;
      if isempty(k_rest)==0;
         old_Rmat_lr = old_Rmat_lr(k_rest,:);
         Rmat_lr = Rmat_lr(k_rest,:);
         rvec_lr = rvec_lr(k_rest,1);
      else;
         old_Rmat_lr = zeros(1,size(old_Rmat_lr,2));
         Rmat_lr = zeros(1,size(Rmat_lr,2));
         rvec_lr = 0;
      end;
   end;
   %
   % need to check the number of restrictions
   %
   Rmat = [Rmat_sr;Rmat_lr];
   rvec = [rvec_sr;rvec_lr];
   num_res = rank(Rmat);
   tot_res = size(Rmat,1);
   keep_rest_global = (1:1:tot_res)';
   del_rest_global = [];
   if rank(Rmat)==size(Rmat,1);
      if rank(Rmat)<(tm.n*(tm.n-1))/2;
         return;
      end;
   else;
      %
      % need to see if we can do anything about the rank
      %
      if rank(Rmat)>=(tm.n*(tm.n-1))/2;
         [del_rest_l,keep_rest_l] = getdelvars(Rmat',[]);
         if size(keep_rest_l,1)<(tm.n*(tm.n-1))/2;
            status = 3;
            return;
         end;
         if isempty(del_rest_l)==1;
            status = 3;
            return;
         end;
      else;
         status = 3;
         return;
      end;
   end;
   %
   Nn = ncommutation(tm.n);
   if tm.restrict(1,1)==1;
      file = strcat(tm.modelsdir,'G-',int2str(tm.n),'x',int2str(tm.r),'-',tm.modelfile,'.rest');
      G = loaddata(file);
      [Rmat_alpha,rvec_alpha] = rmatrix(G,tm.n,tm.r);
      if isempty(tm.Z2)==0;
         Rmat_alpha = [zeros(size(G,1),size(tm.Z2,1)*tm.n) Rmat_alpha];
      end;
      xi = xi_mat(C,tm.Psi,tm.alpha,tm.p,tm.pe,tm.r,tm.d,tm.q1,tm.q0);
   else;
      Rmat_alpha = [];
   end;
   %
   % Check if we have restrictions on C
   %
   if (size(tm.restrict,2)==3)&(tm.restrict(1,3)==1);
      file = strcat(tm.modelsdir,'C-',int2str(tm.n),'x',int2str(tm.r),'-',tm.modelfile,'.rest');
      Cres = loaddata(file);
      [Rmat_C,rvec_C] = rmatrix(Cres,tm.n,tm.n);
      xi = xi_mat(C,tm.Psi,tm.alpha,tm.p,tm.pe,tm.r,tm.d,tm.q1,tm.q0);
      g_c = Rmat_C*kron(xi',C);
      if rank(g_c)<size(g_c,1);
         [red_rest,use_rest] = getdelvars(g_c',[]);
         Rmat_C = Rmat_C(use_rest,:);
         rvec_C = rvec_C(use_rest,1);
      end;
   else;
      Rmat_C = [];
      rvec_C = [];
   end;
   n_states = size(Rmat_lr,1);
   %
   % check if we have already saved the necessary data to do estimation
   %
   file = strcat(tm.modelsdir,'structural-rest-',type_var,'-',int2str(tm.n),'x',int2str(tm.r),'x',int2str(tot_res),'x',int2str(n_states),'-',num2str(tm.restrict(1,2)),'x',num2str(tm.restrict(1,1)),'x',num2str(size(Rmat_alpha,1)),'-',num2str(tm.restrict(1,3)),'x',num2str(size(Rmat_C,1)),'-',tm.modelfile,'.mat');
   if fileexist(file)==1;
      my_rest = load(file);
      if (isfield(my_rest,'keep_rest')==1)&(isfield(my_rest,'del_rest')==1)&(isfield(my_rest,'use_psi_rest')==1);
         %
         % need to check the date of 3 files
         %
         % 1. stored_date for the mat-file
         % 2. lr_date for the LR restrictions file
         % 3. sr_date for the contemporaneous restrictions file
         %
         % in addition to any restrictions files for beta and alpha
         %
         stored_date = getfiledate(file);
         %
         file = strcat(tm.modelsdir,'LF-',int2str(tm.n),'x',int2str(tm.r),'-',tm.modelfile,'.rest');
         lr_date = getfiledate(file);
         %
         file = strcat(tm.modelsdir,'F-',int2str(tm.n),'x',int2str(tm.r),'-',tm.modelfile,'.rest');
         sr_date = getfiledate(file);
         %
         % we should also check all relevant restrictions on beta, alpha and C
         %
         if tm.restrict(1,2)==1;
            beta_test = 1;
            alpha_test = 1;
            for i=1:tm.r;
               file = strcat(tm.modelsdir,'H_',num2str(i),'-',num2str(tm.n),'x',num2str(tm.r),'x',num2str(tm.dcoint+tm.q1),'-',tm.modelfile,'.rest');
               beta_date = getfiledate(file);
               if beta_date>stored_date;
                  beta_test = 0;
                  break;
               end;
            end;
            %
            % now we do the alpha file
            %
            if (beta_test==1)&(tm.restrict(1,1)==1);
               file = strcat(tm.modelsdir,'G-',int2str(tm.n),'x',int2str(tm.r),'-',tm.modelfile,'.rest');
               alpha_date = getfiledate(file);
               if alpha_date>stored_date;
                  alpha_test = 0;
               end;
            end;
         else;
            beta_test = 1;
            alpha_test = 1;
         end;
         %
         % now we do the C file
         %
         if tm.restrict(1,3)==1;
            c_test = 1;
            file = strcat(tm.modelsdir,'C-',int2str(tm.n),'x',int2str(tm.r),'-',tm.modelfile,'.rest');
            c_date = getfiledate(file);
            if c_date>stored_date;
               c_test = 0;
            end;
         else;
            c_test = 1;
         end;
         %
         % now we check if stored_date is more recent than the other 2
         %
         if (stored_date>lr_date)&(stored_date>sr_date)&(beta_test==1)&(alpha_test==1)&(c_test==1);
            status = 0;
            keep_rest = my_rest.keep_rest;
            del_rest = my_rest.del_rest;
            use_psi_rest = my_rest.use_psi_rest;
            %
            % before we leave we should return a B_random matrix
            %
            new_Rmat = Rmat(keep_rest.entry(1,1).rest,:);
            new_rvec = rvec(keep_rest.entry(1,1).rest,1);
            S = null(new_Rmat);
            H_Rmat = null(S');
            d = (H_Rmat/(new_Rmat*H_Rmat))*new_rvec;
            vB = (S*randn(size(S,2),1))+d;
            B_random = vecinv(vB,tm.n);
            return;
         end;
      end;
   end;
   %
   % construct the necessary data for estimation or signal bad restrictions
   %
   oid_rest = (size(Rmat_lr,1)+size(Rmat_sr,1)-((tm.n*(tm.n-1))/2));
   if oid_rest==0;
      states = zeros(1,n_states);
   else;
      if strcmp(computer,'PCWIN')==1;
         file = [pwd '\mat\states-' num2str(n_states,'%0.0f') '.' num2str(oid_rest,'%0.0f') '.mat'];
      else;
         file = [pwd '/mat/states-' num2str(n_states,'%0.0f') '.' num2str(oid_rest,'%0.0f') '.mat'];
      end;
      if fileexist(file)==1;
         states_data = load(file);
         states = states_data.states;
         clear('states_data');
      else;
         %
         % ask if we should proceed
         %
         txt = ['Structural VAR needs to calculate all combinations of ' num2str(n_states,'%0.0f') ' states. This may take some time, but is only needed once. Are you sure you want to continue?'];
         answer = query(txt,'question',120,'Structural VAR - Combinations',500,'no');
         if strcmp(answer,'Yes')==1;
            %
            % show a wait dialog
            %
            txt = strvcat(' ',['Determining the number of combinations of ' num2str(n_states,'%0.0f') ' states to test for local identification...'],'Please hold!');
            mywait = waitdlg(txt,'information');
            waitf = get(mywait,'UserData');
            states = var_comb(n_states);
            txt = strvcat(' ','Saving data to file...','Please hold!');
            set(waitf.text,'String',txt);
            %
            % save to disk
            %
            if strcmp(computer,'PCWIN')==1;
               file = [pwd '\mat\states-' num2str(n_states,'%0.0f') '.' num2str(n_states,'%0.0f') '.mat'];
            else;
               file = [pwd '/mat/states-' num2str(n_states,'%0.0f') '.' num2str(n_states,'%0.0f') '.mat'];
            end;
            %
            save(file,'states');
            %
            f_states = states;
            clear('states');
            %
            if n_states>1;
               for j=1:n_states-1;
                  if j<n_states-1;
                     states = [];
                     for k=1:size(f_states,1);
                        stat_r = f_states(k,:);
                        stat_r = stat_r(stat_r~=0);
                        if size(stat_r,2)<=j;
                           states = [states;f_states(k,:)];
                        end;
                     end;
                  else;
                     states = f_states(1:size(f_states,1)-1,:);
                  end;
                  if strcmp(computer,'PCWIN')==1;
                     file = [pwd '\mat\states-' num2str(n_states,'%0.0f') '.' num2str(j,'%0.0f') '.mat'];
                  else;
                     file = [pwd '/mat/states-' num2str(n_states,'%0.0f') '.' num2str(j,'%0.0f') '.mat'];
                  end;
                  save(file,'states');
               end;
               clear('states');
            end;
            clear('f_states');
            %
            % now load the correct file with states
            %
            if strcmp(computer,'PCWIN')==1;
               file = [pwd '\mat\states-' num2str(n_states,'%0.0f') '.' num2str(oid_rest,'%0.0f') '.mat'];
            else;
               file = [pwd '/mat/states-' num2str(n_states,'%0.0f') '.' num2str(oid_rest,'%0.0f') '.mat'];
            end;
            states_data = load(file);
            states = states_data.states;
            clear('states_data');
            %
            % close wait dialog
            %
            set(waitf.text,'UserData','done');
            delete(mywait);
         else;
            status = 6;
         end;
      end;
   end;
   %
   % initialize the different case checks
   %
   abort = '';
   success_num = 0;
   i_state = 0;
   if status==6;
      return;
   end;
   while (i_state<=size(states,1)-1)&(strcmp(abort,'cancel')==0);
      i_state = i_state+1;
      %
      % open the progress dialog
      %
      if i_state==1;
         %
         % set up a progress bar
         %
         num_trials = size(states,1);
         input_var.title = ['Progress for maximum of ' int2str(num_trials) ' trials'];
         input_var.facecolor = curr_ini.progress_facecolor;
         input_var.startfacecolor = curr_ini.progress_startfacecolor;
         input_var.edgecolor = curr_ini.progress_edgecolor;
         input_var.bgcolor = curr_ini.progress_bgcolor;
         input_var.label = 'Trial number:';
         input_var.stop = 0;
         input_var.clock = 1;
         input_var.name = 'Checking Long-Run Restrictions';
         mywait = progressdlg(0,input_var);
%         set(mywait,'Name','Checking Long-Run Restrictions');
         set(mywait,'Color',get(0,'defaultuicontrolbackgroundcolor'));
         drawnow;
      elseif i_state>1;
         %
         % update the progress bar
         %
         abort = get(mywait,'UserData');
         if strcmp(abort,'cancel')==0;
            progressdlg([(i_state/num_trials) i_state]);
         end;
      end;
      %
      % create new del_rest_local and keep_rest_local variables
      %
      r_num = states(i_state,:);
      r_num = r_num(r_num~=0);
      %
      if isempty(r_num)==0;
         r_num = (r_num')+size(Rmat_sr,1);
      end;
      del_rest_local = unique([del_rest_global;r_num]);
      keep_rest_local = setdiff(keep_rest_global,del_rest_local);
      %
      % create new restrictions matrices and check their rank
      %
      new_Rmat = Rmat(keep_rest_local,:);
      new_rvec = rvec(keep_rest_local,1);
      %
      % we only need to evaluate those cases where new_Rmat has
      % full row rank
      %
      if rank(new_Rmat)==size(new_Rmat,1);
         %
         % Now we create a random B matrix and check its rank
         %
         S = null(new_Rmat);
         d = (new_Rmat'/(new_Rmat*new_Rmat'))*new_rvec;
         vB = (S*randn(size(S,2),1))+d;
         B_rand = vecinv(vB,tm.n);
         if rank(B_rand)==tm.n;
            %
            % with B_rand having the correct rank we next need to check a random
            % C satisfying all the long-run restrictions
            %
            %
            % create the linear restrictions on C
            %
            c_Rmat = old_Rmat_lr*kron(B_rand',beta_orth);
            c_rvec = rvec_lr;
            if (size(tm.restrict,2)==3)&(tm.restrict(1,3)==1);
               c_Rmat = [Rmat_C*kron(eye(tm.n),beta_orth);c_Rmat];
               c_rvec = [rvec_C;c_rvec];
               if rank(c_Rmat)<size(c_Rmat,1);
                  [red_rest_h,use_rest_h] = getdelvars(c_Rmat',[]);
                  c_Rmat = c_Rmat(use_rest_h,:);
                  c_rvec = c_rvec(use_rest_h,1);
               end;
            end;
            %
            % create a C which can satisfies the del_rest_local restrictions and which
            % should be able to have the correct rank
            %
            S_c = null(c_Rmat);
            H_c = null(S_c');
            d_c = (H_c/(c_Rmat*H_c))*c_rvec;
            psi_c = (S_c'*S_c)\(S_c'*(vec(Gamma_mat)-d_c));
            vC = (S_c*psi_c)+d_c;
            if (tm.r==0)|(tm.r==tm.n);
               C_new = vecinv(vC,tm.n);
            else;
               C_new = beta_orth*vecinv(vC,tm.n-tm.r);
            end;
            %
            % now check if B_rand and C_new satisfy all long-run restrictions
            %
            rest_values = (old_Rmat_lr*vec(C_new*B_rand))-rvec_lr;
            %
            % now add the C restrictions to rest_values if applicable
            %
            if (size(tm.restrict,2)==3)&(tm.restrict(1,3)==1);
               rest_values = [rest_values;Rmat_C*vec(C_new)-rvec_C];
            end;
            %
            if (max(abs(rest_values))<1.0e-008)&(rank(C_new)==rank(C));
               %
               % At this stage both B_rand and C_new are valid, i.e. B_rand
               % has full rank, C_new has the same rank as C, and C_new*B_rand
               % satisfy all long-run restrictions
               %
               % we need to check how the long-run restrictions interact with restrictions
               % on alpha
               %
               if tm.restrict(1,1)==1;
                  if (size(tm.restrict,2)==3)&(tm.restrict(1,3)==1);
                     c_Rmat = [Rmat_alpha;Rmat_C*kron(xi',C);old_Rmat_lr*kron(B_rand'*xi',C)];
                  else;
                     c_Rmat = [Rmat_alpha;old_Rmat_lr*kron(B_rand'*xi',C)];
                  end;
                  if rank(c_Rmat)<size(c_Rmat,1);
                     [red_rest_local,use_psi_rest_local] = getdelvars(c_Rmat',[]);
                     red_rest_local = red_rest_local-rank([Rmat_alpha;Rmat_C*kron(xi',C)]);
                  else;
                     use_psi_rest_local = (1:1:size(c_Rmat,1))';
                  end;
               else;
                  if (size(tm.restrict,2)==3)&(tm.restrict(1,3)==1);
                     c_Rmat = [Rmat_C*kron(xi',C);old_Rmat_lr*kron(B_rand'*xi',C)];
                     if rank(c_Rmat)<size(c_Rmat,1);
                        [red_rest_local,use_psi_rest_local] = getdelvars(c_Rmat',[]);
                        red_rest_local = red_rest_local-size(Rmat_C,1);
                     else;
                        use_psi_rest_local = (1:1:size(c_Rmat,1))';
                     end;
                  else;
                     use_psi_rest_local = (1:1:size(old_Rmat_lr,1))';
                  end;
               end;
               %
               % we should select an Rmat version which uses C_new
               % creating a new B_rand and check its rank
               %
               B_Rmat = [Rmat_sr;old_Rmat_lr*kron(eye(tm.n),C_new)];
               B_Rmat = B_Rmat(keep_rest_local,:);
               if rank(B_Rmat)==size(B_Rmat,1);
                  B_rvec = rvec(keep_rest_local,1);
                  S = null(B_Rmat);
                  H_Rmat = null(S');
                  d = (H_Rmat/(B_Rmat*H_Rmat))*B_rvec;
                  vB = (S*randn(size(S,2),1))+d;
                  B_rand = vecinv(vB,tm.n);
                  %
                  if rank(B_rand)==tm.n;
                     %
                     % Need to check for local identification of B_rand using Rothenberg (1971, Theorem 2)
                     % and that S'*info_mat*S is invertible
                     %
                     B_inv = B_rand\eye(tm.n);
                     i_b = kron(eye(tm.n),B_inv);
                     info_mat = 2*i_b'*Nn*i_b;
                     g_info = S'*info_mat*S;
                     if rank(g_info)==size(g_info,1);
                        test_mat = [info_mat;B_Rmat];
                        if rank(test_mat,eps)==floor(tm.n*tm.n);
                           success_num = success_num+1;
                           keep_rest.entry(success_num,1).rest = keep_rest_local;
                           del_rest.entry(success_num,1).rest = del_rest_local;
                           use_psi_rest.entry(success_num,1).rest = use_psi_rest_local;
                           status = 0;
                           B_random = B_rand;
                        end;
                     end;
                  end;

               end;
            end;
         end;
      end;
   end;
   %
   % close down the progress dialog
   %
   set(mywait,'UserData','done');
   close(mywait);
   drawnow;
   clear('states');
   %
   if strcmp(abort,'cancel')==1;
      status = 7;
   else;
      %
      % save data to file if we have any data to save
      %
      if status==0;
         file = strcat(tm.modelsdir,'structural-rest-',type_var,'-',int2str(tm.n),'x',int2str(tm.r),'x',int2str(tot_res),'x',int2str(n_states),'-',num2str(tm.restrict(1,2)),'x',num2str(tm.restrict(1,1)),'x',num2str(size(Rmat_alpha,1)),'-',num2str(tm.restrict(1,3)),'x',num2str(size(Rmat_C,1)),'-',tm.modelfile,'.mat');
         save(file,'keep_rest','del_rest','use_psi_rest');
      end;
   end;
end;

%
% end of test_ident_m2.m
%
